@@ -3,15 +3,18 @@
 /**
  * mime.class
  *
- * Copyright (c) 2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
+ * This file loads classes needed to handle mime messages.
  *
- * This contains functions needed to handle mime messages.
- *
- * $Id: mime.class.php,v 1.41 2003/10/28 21:30:49 tassium Exp $
+ * @copyright &copy; 2003-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: mime.class.php,v 1.49 2006/01/23 18:39:32 tokul Exp $
  * @package squirrelmail
+ * @subpackage mime
  */
 
+/** @ignore */
+if (! defined('SM_PATH')) define('SM_PATH','../');
+
 /** Load in the entire MIME system */
 require_once(SM_PATH . 'class/mime/Rfc822Header.class.php');
 require_once(SM_PATH . 'class/mime/MessageHeader.class.php');
@@ -22,4 +25,4 @@ require_once(SM_PATH . 'class/mime/Disposition.class.php');
 require_once(SM_PATH . 'class/mime/Language.class.php');
 require_once(SM_PATH . 'class/mime/ContentType.class.php');
 
-?>
+?>
\ No newline at end of file
