@@ -3,26 +3,56 @@
 /**
  * AddressStructure.class.php
  *
- * Copyright (c) 2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
+ * This file contains functions needed to extract email address headers from
+ * mime messages.
  *
- * This contains functions needed to handle mime messages.
- *
- * $Id: AddressStructure.class.php,v 1.7 2003/10/28 21:30:50 tassium Exp $
+ * @copyright &copy; 2003-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: AddressStructure.class.php,v 1.16 2006/01/23 18:39:32 tokul Exp $
  * @package squirrelmail
+ * @subpackage mime
+ * @since 1.3.2
  */
 
 /**
- * Undocumented class
+ * Class used to work with email address headers
  * @package squirrelmail
+ * @subpackage mime
+ * @since 1.3.2
  */
 class AddressStructure {
-    var $personal = '',
-        $adl      = '',
-        $mailbox  = '',
-        $host     = '',
-        $group    = '';
+    /**
+     * Personal information
+     * @var string
+     */
+    var $personal = '';
+    /**
+     * @todo check use of this variable. var is not used in class.
+     * @var string
+     */
+    var $adl      = '';
+    /**
+     * Mailbox name.
+     * @var string
+     */
+    var $mailbox  = '';
+    /**
+     * Server address.
+     * @var string
+     */
+    var $host     = '';
+    /**
+     * @todo check use of this variable. var is not used in class.
+     * @var string
+     */
+    var $group    = '';
 
+    /**
+     * Return address information from mime headers.
+     * @param boolean $full return full address (true) or only personal if it exists, otherwise email (false)
+     * @param boolean $encoded (since 1.4.0) return rfc2047 encoded address (true) or plain text (false).
+     * @return string
+     */
     function getAddress($full = true, $encoded = false) {
         $result = '';
         if (is_object($this)) {
@@ -47,7 +77,7 @@ class AddressStructure {
                     }
                 }
                 $addr = ($email ? $personal . ' <' .$email.'>'
-                        : $this->personal);                                    
+                        : $this->personal);
                 $best_dpl = $this->personal;
             } else {
                 $addr = $email;
@@ -57,10 +87,16 @@ class AddressStructure {
         }
         return $result;
     }
-    
+
+    /**
+     * Shorter version of getAddress() function
+     * Returns full encoded address.
+     * @return string
+     * @since 1.4.0
+     */
     function getEncodedAddress() {
         return $this->getAddress(true, true);
     }
 }
 
-?>
+?>
\ No newline at end of file
