@@ -3,14 +3,10 @@
 /**
  * db_prefs.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This contains functions for manipulating user preferences
  * stored in a database, accessed though the Pear DB layer.
  *
  * Database:
- * ---------
  *
  * The preferences table should have three columns:
  *    user       char  \  primary
@@ -25,10 +21,17 @@
  * Configuration of databasename, username and password is done
  * by using conf.pl or the administrator plugin
  *
- * $Id: db_prefs.php,v 1.32 2003/10/28 21:27:46 tassium Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: db_prefs.php,v 1.46 2006/01/23 18:39:32 tokul Exp $
  * @package squirrelmail
+ * @subpackage prefs
+ * @since 1.1.3
  */
 
+/** @ignore */
+if (!defined('SM_PATH')) define('SM_PATH','../');
+
 /** Unknown database */
 define('SMDB_UNKNOWN', 0);
 /** MySQL */
@@ -36,15 +39,29 @@ define('SMDB_MYSQL', 1);
 /** PostgreSQL */
 define('SMDB_PGSQL', 2);
 
-require_once('DB.php');
 require_once(SM_PATH . 'config/config.php');
+if (!include_once('DB.php')) {
+    // same error also in abook_database.php
+    require_once(SM_PATH . 'functions/display_messages.php');
+    $error  = _("Could not include PEAR database functions required for the database backend.") . "<br />\n";
+    $error .= sprintf(_("Is PEAR installed, and is the include path set correctly to find %s?"),
+                        '<tt>DB.php</tt>') . "<br />\n";
+    $error .= _("Please contact your system administrator and report this error.");
+    error_box($error, $color);
+    exit;
+}
 
 global $prefs_are_cached, $prefs_cache;
 
+/**
+ * @ignore
+ */
 function cachePrefValues($username) {
     global $prefs_are_cached, $prefs_cache;
 
+    sqgetGlobalVar('prefs_are_cached', $prefs_are_cached, SQ_SESSION );
     if ($prefs_are_cached) {
+        sqgetGlobalVar('prefs_cache', $prefs_cache, SQ_SESSION );
         return;
     }
 
@@ -72,25 +89,84 @@ function cachePrefValues($username) {
 }
 
 /**
- * Completely undocumented class - someone document it!
+ * Class used to handle connections to prefs database and operations with preferences
  * @package squirrelmail
+ * @subpackage prefs
+ * @since 1.1.3
  */
 class dbPrefs {
+    /**
+     * Table used to store preferences
+     * @var string
+     */
     var $table = 'userprefs';
+    /**
+     * Field used to store owner of preference
+     * @var string
+     */
     var $user_field = 'user';
+    /**
+     * Field used to store preference name
+     * @var string
+     */
     var $key_field = 'prefkey';
+    /**
+     * Field used to store preference value
+     * @var string
+     */
     var $val_field = 'prefval';
 
+    /**
+     * Database connection object
+     * @var object
+     */
     var $dbh   = NULL;
+    /**
+     * Error messages
+     * @var string
+     */
     var $error = NULL;
+    /**
+     * Database type (SMDB_* constants)
+     * Is used in setKey().
+     * @var integer
+     */
     var $db_type = SMDB_UNKNOWN;
 
+    /**
+     * Default preferences
+     * @var array
+     */
     var $default = Array('theme_default' => 0,
                          'show_html_default' => '0');
 
+    /**
+     * Preference owner field size
+     * @var integer
+     * @since 1.5.1
+     */
+    var $user_size = 128;
+    /**
+     * Preference key field size
+     * @var integer
+     * @since 1.5.1
+     */
+    var $key_size = 64;
+    /**
+     * Preference value field size
+     * @var integer
+     * @since 1.5.1
+     */
+    var $val_size = 65536;
+
+    /**
+     * initialize DB connection object
+     * @return boolean true, if object is initialized
+     */
     function open() {
         global $prefs_dsn, $prefs_table;
         global $prefs_user_field, $prefs_key_field, $prefs_val_field;
+        global $prefs_user_size, $prefs_key_size, $prefs_val_size;
 
         if(isset($this->dbh)) {
             return true;
@@ -114,6 +190,15 @@ class dbPrefs {
         if (!empty($prefs_val_field)) {
             $this->val_field = $prefs_val_field;
         }
+        if (!empty($prefs_user_size)) {
+            $this->user_size = (int) $prefs_user_size;
+        }
+        if (!empty($prefs_key_size)) {
+            $this->key_size = (int) $prefs_key_size;
+        }
+        if (!empty($prefs_val_size)) {
+            $this->val_size = (int) $prefs_val_size;
+        }
         $dbh = DB::connect($prefs_dsn, true);
 
         if(DB::isError($dbh)) {
@@ -125,6 +210,10 @@ class dbPrefs {
         return true;
     }
 
+    /**
+     * Function used to handle database connection errors
+     * @param object PEAR Error object 
+     */
     function failQuery($res = NULL) {
         if($res == NULL) {
             printf(_("Preference database error (%s). Exiting abnormally"),
@@ -136,7 +225,13 @@ class dbPrefs {
         exit;
     }
 
-
+    /**
+     * Get user's prefs setting
+     * @param string $user user name
+     * @param string $key preference name
+     * @param mixed $default (since 1.2.5) default value
+     * @return mixed preference value
+     */
     function getKey($user, $key, $default = '') {
         global $prefs_cache;
 
@@ -153,6 +248,12 @@ class dbPrefs {
         }
     }
 
+    /**
+     * Delete user's prefs setting
+     * @param string $user user name 
+     * @param string $key preference name
+     * @return boolean
+     */
     function deleteKey($user, $key) {
         global $prefs_cache;
 
@@ -176,10 +277,60 @@ class dbPrefs {
         return true;
     }
 
+    /**
+     * Set user's preference
+     * @param string $user user name
+     * @param string $key preference name
+     * @param mixed $value preference value
+     * @return boolean
+     */
     function setKey($user, $key, $value) {
         if (!$this->open()) {
             return false;
         }
+
+        /**
+         * Check if username fits into db field
+         */
+        if (strlen($user) > $this->user_size) {
+            $this->error = "Oversized username value."
+                ." Your preferences can't be saved."
+                ." See doc/db-backend.txt or contact your system administrator.";
+
+            /**
+             * Debugging function. Can be used to log all issues that trigger 
+             * oversized field errors. Function should be enabled in all three 
+             * strlen checks. See http://www.php.net/error-log
+             */
+            // error_log($user.'|'.$key.'|'.$value."\n",3,'/tmp/oversized_log');
+
+            // error is fatal
+            $this->failQuery(null);
+        }
+        /**
+         * Check if preference key fits into db field
+         */
+        if (strlen($key) > $this->key_size) {
+            $err_msg = "Oversized user's preference key."
+                ." Some preferences were not saved."
+                ." See doc/db-backend.txt or contact your system administrator.";
+            // error is not fatal. Only some preference is not saved.
+            trigger_error($err_msg,E_USER_WARNING);
+            return false;
+        }
+        /**
+         * Check if preference value fits into db field
+         */
+        if (strlen($value) > $this->val_size) {
+            $err_msg = "Oversized user's preference value."
+                ." Some preferences were not saved."
+                ." See doc/db-backend.txt or contact your system administrator.";
+            // error is not fatal. Only some preference is not saved.
+            trigger_error($err_msg,E_USER_WARNING);
+            return false;
+        }
+
+
         if ($this->db_type == SMDB_MYSQL) {
             $query = sprintf("REPLACE INTO %s (%s, %s, %s) ".
                              "VALUES('%s','%s','%s')",
@@ -250,6 +401,11 @@ class dbPrefs {
         return true;
     }
 
+    /**
+     * Fill preference cache array
+     * @param string $user user name
+     * @since 1.2.3
+     */
     function fillPrefsCache($user) {
         global $prefs_cache;
 
@@ -278,7 +434,10 @@ class dbPrefs {
 } /* end class dbPrefs */
 
 
-/* returns the value for the pref $string */
+/**
+ * returns the value for the pref $string
+ * @ignore
+ */
 function getPref($data_dir, $username, $string, $default = '') {
     $db = new dbPrefs;
     if(isset($db->error)) {
@@ -290,7 +449,10 @@ function getPref($data_dir, $username, $string, $default = '') {
     return $db->getKey($username, $string, $default);
 }
 
-/* Remove the pref $string */
+/**
+ * Remove the pref $string
+ * @ignore
+ */
 function removePref($data_dir, $username, $string) {
     global $prefs_cache;
     $db = new dbPrefs;
@@ -308,7 +470,10 @@ function removePref($data_dir, $username, $string) {
     return;
 }
 
-/* sets the pref, $string, to $set_to */
+/**
+ * sets the pref, $string, to $set_to
+ * @ignore
+ */
 function setPref($data_dir, $username, $string, $set_to) {
     global $prefs_cache;
 
@@ -335,7 +500,10 @@ function setPref($data_dir, $username, $string, $set_to) {
     return;
 }
 
-/* This checks if the prefs are available */
+/**
+ * This checks if the prefs are available
+ * @ignore
+ */
 function checkForPrefs($data_dir, $username) {
     $db = new dbPrefs;
     if(isset($db->error)) {
@@ -343,7 +511,10 @@ function checkForPrefs($data_dir, $username) {
     }
 }
 
-/* Writes the Signature */
+/**
+ * Writes the Signature
+ * @ignore
+ */
 function setSig($data_dir, $username, $number, $string) {
     if ($number == "g") {
         $key = '___signature___';
@@ -354,7 +525,10 @@ function setSig($data_dir, $username, $number, $string) {
     return;
 }
 
-/* Gets the signature */
+/**
+ * Gets the signature
+ * @ignore
+ */
 function getSig($data_dir, $username, $number) {
     if ($number == "g") {
         $key = '___signature___';
@@ -364,4 +538,5 @@ function getSig($data_dir, $username, $number) {
     return getPref($data_dir, $username, $key);
 }
 
-?>
+// vim: et ts=4
+?>
\ No newline at end of file
