@@ -3,15 +3,14 @@
 /**
  * functions/decode/us_ascii.php
  *
- * Copyright (c) 2004 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This file contains us-ascii decoding function that is needed to read
  * us-ascii encoded mails in non-us-ascii locale.
  *
  * Function replaces all 8bit symbols with '?' marks
  *
- * $Id: us_ascii.php,v 1.1 2004/01/29 19:37:29 tokul Exp $
+ * @copyright &copy; 2004-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: us_ascii.php,v 1.8 2006/01/23 18:39:33 tokul Exp $
  * @package squirrelmail
  * @subpackage decode
  */
@@ -23,12 +22,8 @@
  * @return string cleaned string
  */
 function charset_decode_us_ascii ($string) {
-    global $default_charset;
-
-    if (strtolower($default_charset) == 'us-ascii')
-        return $string;
-
-    if (! ereg("[\200-\237]", $string) and ! ereg("[\241-\377]", $string) )
+    // don't do decoding when there are no 8bit symbols
+    if (! sq_is8bit($string,'us-ascii'))
         return $string;
 
     $string = preg_replace("/([\201-\237])/e","'?'",$string);
@@ -39,4 +34,4 @@ function charset_decode_us_ascii ($string) {
     $string = preg_replace("/([\241-\377])/e","'?'",$string);
     return $string;
 }
-?>
+?>
\ No newline at end of file
