@@ -6,9 +6,9 @@
  * takes a string of unicode entities and converts it to a cp1255 encoded string
  * Unsupported characters are replaced with ?.
  *
- * @copyright 2004-2019 The SquirrelMail Project Team
+ * @copyright &copy; 2004-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: cp1255.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * @version $Id: cp1255.php,v 1.6 2006/01/23 18:41:25 tokul Exp $
  * @package squirrelmail
  * @subpackage encode
  */
@@ -22,7 +22,8 @@ function charset_encode_cp1255 ($string) {
    // don't run encoding function, if there is no encoded characters
    if (! preg_match("'&#[0-9]+;'",$string) ) return $string;
 
-    $string=preg_replace_callback("/&#([0-9]+);/",'unicodetocp1255',$string);
+    $string=preg_replace("/&#([0-9]+);/e","unicodetocp1255('\\1')",$string);
+    // $string=preg_replace("/&#[xX]([0-9A-F]+);/e","unicodetocp1255(hexdec('\\1'))",$string);
 
     return $string;
 }
@@ -35,11 +36,10 @@ function charset_encode_cp1255 ($string) {
  * Don't use it or make sure, that functions/encode/cp1255.php is
  * included.
  *
- * @param array $matches array with first element a decimal unicode value
+ * @param int $var decimal unicode value
  * @return string cp1255 character
  */
-function unicodetocp1255($matches) {
-    $var = $matches[1];
+function unicodetocp1255($var) {
 
     $cp1255chars=array('160' => "\xA0",
                        '161' => "\xA1",
@@ -154,3 +154,4 @@ function unicodetocp1255($matches) {
     }
     return $ret;
 }
+?>
\ No newline at end of file
