@@ -10,9 +10,9 @@
  * Original code is taken from www.php.net manual comments
  * Original author: ronen at greyzone dot com
  *
- * @copyright 2004-2019 The SquirrelMail Project Team
+ * @copyright &copy; 2004-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: utf_8.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * @version $Id: utf_8.php,v 1.11 2006/01/23 18:41:25 tokul Exp $
  * @package squirrelmail
  * @subpackage encode
  */
@@ -26,7 +26,8 @@ function charset_encode_utf_8 ($string) {
    // don't run encoding function, if there is no encoded characters
    if (! preg_match("'&#[0-9]+;'",$string) ) return $string;
 
-    $string=preg_replace_callback("/&#([0-9]+);/",'unicodetoutf8',$string);
+    $string=preg_replace("/&#([0-9]+);/e","unicodetoutf8('\\1')",$string);
+    // $string=preg_replace("/&#[xX]([0-9A-F]+);/e","unicodetoutf8(hexdec('\\1'))",$string);
 
     return $string;
 }
@@ -39,11 +40,10 @@ function charset_encode_utf_8 ($string) {
  * Don't use it or make sure, that functions/encode/utf_8.php is
  * included.
  *
- * @param array $matches array with first element a decimal unicode value
+ * @param int $var decimal unicode value
  * @return string utf8 character
  */
-function unicodetoutf8($matches) {
-    $var = $matches[1];
+function unicodetoutf8($var) {
 
     if ($var < 128) {
         $ret = chr ($var);
@@ -118,3 +118,4 @@ function unicodetoutf8($matches) {
     }
     return $ret;
 }
+?>
\ No newline at end of file
