@@ -3,31 +3,40 @@
 /**
  * file_prefs.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This contains functions for manipulating user preferences in files
  *
- * $Id: file_prefs.php,v 1.29 2003/10/28 21:27:46 tassium Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: file_prefs.php,v 1.43 2006/01/23 18:39:32 tokul Exp $
  * @package squirrelmail
+ * @subpackage prefs
+ * @since 1.2.5
  */
 
+/** @ignore */
+if (! defined('SM_PATH')) define('SM_PATH','../');
+
 /** include this for error messages */
 include_once(SM_PATH . 'functions/display_messages.php');
 
 /**
  * Check the preferences into the session cache.
+ * @param string $data_dir
+ * @param string $username
+ * @since 1.1.3
  */
 function cachePrefValues($data_dir, $username) {
     global $prefs_are_cached, $prefs_cache;
-       
+
+    sqgetGlobalVar('prefs_are_cached', $prefs_are_cached, SQ_SESSION );
     if ( isset($prefs_are_cached) && $prefs_are_cached) {
+        sqgetGlobalVar('prefs_cache', $prefs_cache, SQ_SESSION );
         return;
     }
-    
+
     sqsession_unregister('prefs_cache');
     sqsession_unregister('prefs_are_cached');
-    
+
     /* Calculate the filename for the user's preference file */
     $filename = getHashedFile($username, $data_dir, "$username.pref");
 
@@ -82,34 +91,42 @@ function cachePrefValues($data_dir, $username) {
     sqsession_register($prefs_cache, 'prefs_cache');
     sqsession_register($prefs_are_cached, 'prefs_are_cached');
 }
-   
+
 /**
  * Return the value for the preference given by $string.
+ * @param string $data_dir data directory
+ * @param string $username user name
+ * @param string $string preference name
+ * @param string $default (since 1.2.0) default preference value
+ * @return mixed
  */
 function getPref($data_dir, $username, $string, $default = '') {
     global $prefs_cache;
 
     $result = do_hook_function('get_pref_override',array($username,$string));
     if (!$result) {
-	cachePrefValues($data_dir, $username);
-	if (isset($prefs_cache[$string])) {
-    	    $result = $prefs_cache[$string];
-	} else {
-	    $result = do_hook_function('get_pref', array($username,$string));
-	    if (!$result) {	    
-    		$result = $default;
-	    }
-	}
+        cachePrefValues($data_dir, $username);
+        if (isset($prefs_cache[$string])) {
+            $result = $prefs_cache[$string];
+        } else {
+            $result = do_hook_function('get_pref', array($username,$string));
+            if (!$result) {
+                $result = $default;
+            }
+        }
     }
     return ($result);
 }
 
 /**
  * Save the preferences for this user.
+ * @param string $data_dir data directory
+ * @param string $username user name
+ * @since 1.1.3
  */
 function savePrefValues($data_dir, $username) {
     global $prefs_cache;
-   
+
     $filename = getHashedFile($username, $data_dir, "$username.pref");
 
     /* Open the file for writing, or else display an error to the user. */
@@ -120,7 +137,7 @@ function savePrefValues($data_dir, $username) {
     }
     foreach ($prefs_cache as $Key => $Value) {
         if (isset($Value)) {
-            if ( @fwrite($file, $Key . '=' . $Value . "\n") === FALSE ) {
+            if ( sq_fwrite($file, $Key . '=' . $Value . "\n") === FALSE ) {
                logout_error( sprintf( _("Preference file, %s, could not be written. Contact your system administrator to resolve this issue.") , $filename . '.tmp') );
                exit;
             }
@@ -138,21 +155,28 @@ function savePrefValues($data_dir, $username) {
 
 /**
  * Remove a preference for the current user.
+ * @param string $data_dir data directory
+ * @param string $username user name
+ * @param string $string preference name
  */
 function removePref($data_dir, $username, $string) {
     global $prefs_cache;
 
     cachePrefValues($data_dir, $username);
- 
+
     if (isset($prefs_cache[$string])) {
         unset($prefs_cache[$string]);
     }
- 
+
     savePrefValues($data_dir, $username);
 }
 
 /**
  * Set a there preference $string to $value.
+ * @param string $data_dir data directory
+ * @param string $username user name
+ * @param string $string preference name
+ * @param mixed $value preference value
  */
 function setPref($data_dir, $username, $string, $value) {
     global $prefs_cache;
@@ -173,6 +197,10 @@ function setPref($data_dir, $username, $string, $value) {
 
 /**
  * Check for a preferences file. If one can not be found, create it.
+ * @param string $data_dir data directory
+ * @param string $username user name
+ * @param string $filename (since 1.2.0) preference file name.
+ *  detects file name, if set to empty string.
  */
 function checkForPrefs($data_dir, $username, $filename = '') {
     /* First, make sure we have the filename. */
@@ -182,35 +210,42 @@ function checkForPrefs($data_dir, $username, $filename = '') {
 
     /* Then, check if the file exists. */
     if (!@file_exists($filename) ) {
-        /* First, check the $data_dir for the default preference file. */
+
+        /* If it does not exist, check for default_prefs */
+
+        /* First, check legacy locations: data dir */
         if(substr($data_dir,-1) != '/') {
             $data_dir .= '/';
         }
         $default_pref = $data_dir . 'default_pref';
 
-        /* If it is not there, check the internal data directory. */
+        /* or legacy location: internal data dir */
         if (!@file_exists($default_pref)) {
             $default_pref = SM_PATH . 'data/default_pref';
         }
 
-        /* Otherwise, report an error. */
-        $errTitle = sprintf( _("Error opening %s"), $default_pref );
-        if (!is_readable($default_pref)) {
-            $errString = $errTitle . "<br>\n" .
-                         _("Default preference file not found or not readable!") . "<br>\n" .
-                         _("Please contact your system administrator and report this error.") . "<br>\n";
-            logout_error( $errString, $errTitle );
-            exit;
-        } else if (!@copy($default_pref, $filename)) {
+        /* If no legacies, check where we'd expect it to be located:
+         * under config/ */
+        if (!@file_exists($default_pref)) {
+            $default_pref = SM_PATH . 'config/default_pref';
+        }
+
+        /* If a default_pref file found, try to copy it, if none found,
+         * try to create an empty one. If that fails, report an error.
+         */
+        if (
+            ( is_readable($default_pref) && !@copy($default_pref, $filename) ) ||
+            !@touch($filename)
+        ) {
             $uid = 'httpd';
             if (function_exists('posix_getuid')){
                 $user_data = posix_getpwuid(posix_getuid());
                 $uid = $user_data['name'];
             }
-            $errString = $errTitle . '<br>' .
-                       _("Could not create initial preference file!") . "<br>\n" .
-                       sprintf( _("%s should be writable by user %s"), $data_dir, $uid ) .
-                       "<br>\n" . _("Please contact your system administrator and report this error.") . "<br>\n";
+            $errTitle = _("Could not create initial preference file!");
+            $errString = $errTitle . "<br />\n" .
+                       sprintf( _("%s should be writable by user %s"), $data_dir, $uid ) . "<br />\n" .
+                       _("Please contact your system administrator and report this error.") . "<br />\n";
             logout_error( $errString, $errTitle );
             exit;
         }
@@ -219,15 +254,25 @@ function checkForPrefs($data_dir, $username, $filename = '') {
 
 /**
  * Write the User Signature.
+ * @param string $data_dir data directory
+ * @param string $username user name
+ * @param integer $number (since 1.2.5) identity number.
+ *  parameter was used for signature text before 1.2.5.
+ * @param string $value (since 1.2.5) signature text
  */
 function setSig($data_dir, $username, $number, $value) {
+    // Limit signature size to 64KB (database BLOB limit)
+    if (strlen($value)>65536) {
+        error_option_save(_("Signature is too big."));
+        return;
+    }
     $filename = getHashedFile($username, $data_dir, "$username.si$number");
     /* Open the file for writing, or else display an error to the user. */
     if(!$file = @fopen("$filename.tmp", 'w')) {
         logout_error( sprintf( _("Signature file, %s, could not be opened. Contact your system administrator to resolve this issue."), $filename . '.tmp') );
         exit;
     }
-    if ( @fwrite($file, $value) === FALSE ) {
+    if ( sq_fwrite($file, $value) === FALSE ) {
        logout_error( sprintf( _("Signature file, %s, could not be written. Contact your system administrator to resolve this issue.") , $filename . '.tmp'));
        exit;
     }
@@ -243,6 +288,10 @@ function setSig($data_dir, $username, $number, $value) {
 
 /**
  * Get the signature.
+ * @param string $data_dir data directory
+ * @param string $username user name
+ * @param integer $number (since 1.2.5) identity number
+ * @return string signature
  */
 function getSig($data_dir, $username, $number) {
     $filename = getHashedFile($username, $data_dir, "$username.si$number");
@@ -261,3 +310,6 @@ function getSig($data_dir, $username, $number) {
     }
     return $sig;
 }
+
+// vim: et ts=4
+?>
\ No newline at end of file
