@@ -3,19 +3,20 @@
 /**
  * plugin.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This file provides the framework for a plugin architecture.
  *
  * Documentation on how to write plugins might show up some time.
  *
- * $Id: plugin.php,v 1.33 2003/10/29 09:35:51 kink Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: plugin.php,v 1.49 2006/01/28 19:12:19 kink Exp $
  * @package squirrelmail
  */
 
 /** Everything needs global.. */
 require_once(SM_PATH . 'functions/global.php');
+require_once(SM_PATH . 'config/config.php');
+require_once(SM_PATH . 'functions/prefs.php');
 
 global $squirrelmail_plugin_hooks;
 $squirrelmail_plugin_hooks = array();
@@ -41,9 +42,9 @@ function use_plugin ($name) {
  * @return mixed $data
  */
 function do_hook ($name) {
-    global $squirrelmail_plugin_hooks;
+    global $squirrelmail_plugin_hooks, $currentHookName;
     $data = func_get_args();
-    $ret = '';
+    $currentHookName = $name;
 
     if (isset($squirrelmail_plugin_hooks[$name])
           && is_array($squirrelmail_plugin_hooks[$name])) {
@@ -55,6 +56,8 @@ function do_hook ($name) {
         }
     }
 
+    $currentHookName = '';
+
     /* Variable-length argument lists have a slight problem when */
     /* passing values by reference. Pity. This is a workaround.  */
     return $data;
@@ -68,8 +71,9 @@ function do_hook ($name) {
  * @return mixed the return value of the hook function
  */
 function do_hook_function($name,$parm=NULL) {
-    global $squirrelmail_plugin_hooks;
+    global $squirrelmail_plugin_hooks, $currentHookName;
     $ret = '';
+    $currentHookName = $name;
 
     if (isset($squirrelmail_plugin_hooks[$name])
           && is_array($squirrelmail_plugin_hooks[$name])) {
@@ -81,6 +85,8 @@ function do_hook_function($name,$parm=NULL) {
         }
     }
 
+    $currentHookName = '';
+
     /* Variable-length argument lists have a slight problem when */
     /* passing values by reference. Pity. This is a workaround.  */
     return $ret;
@@ -95,8 +101,9 @@ function do_hook_function($name,$parm=NULL) {
  * @return string a concatenation of the results of each plugin function
  */
 function concat_hook_function($name,$parm=NULL) {
-    global $squirrelmail_plugin_hooks;
+    global $squirrelmail_plugin_hooks, $currentHookName;
     $ret = '';
+    $currentHookName = $name;
 
     if (isset($squirrelmail_plugin_hooks[$name])
           && is_array($squirrelmail_plugin_hooks[$name])) {
@@ -108,6 +115,8 @@ function concat_hook_function($name,$parm=NULL) {
         }
     }
 
+    $currentHookName = '';
+
     /* Variable-length argument lists have a slight problem when */
     /* passing values by reference. Pity. This is a workaround.  */
     return $ret;
@@ -127,7 +136,7 @@ function concat_hook_function($name,$parm=NULL) {
  * @return bool the result of the function
  */
 function boolean_hook_function($name,$parm=NULL,$priority=0,$tie=false) {
-    global $squirrelmail_plugin_hooks;
+    global $squirrelmail_plugin_hooks, $currentHookName;
     $yea = 0;
     $nay = 0;
     $ret = $tie;
@@ -136,6 +145,7 @@ function boolean_hook_function($name,$parm=NULL,$priority=0,$tie=false) {
         is_array($squirrelmail_plugin_hooks[$name])) {
 
         /* Loop over the plugins that registered the hook */
+        $currentHookName = $name;
         foreach ($squirrelmail_plugin_hooks[$name] as $function) {
             if (function_exists($function)) {
                 $ret = $function($parm);
@@ -146,6 +156,7 @@ function boolean_hook_function($name,$parm=NULL,$priority=0,$tie=false) {
                 }
             }
         }
+        $currentHookName = '';
 
         /* Examine the aftermath and assign the return value appropriately */
         if (($priority > 0) && ($yea)) {
@@ -169,31 +180,59 @@ function boolean_hook_function($name,$parm=NULL,$priority=0,$tie=false) {
  * This function checks whether the user's USER_AGENT is known to
  * be broken. If so, returns true and the plugin is invisible to the
  * offending browser.
- * This function needs to have its name changed!
+ * *** THIS IS A TEST FOR JAVASCRIPT SUPPORT ***
+ * FIXME: This function needs to have its name changed!
  *
  * @return bool whether this browser properly supports JavaScript
+ * @deprecated use checkForJavascript() since 1.5.1
  */
 function soupNazi(){
-
-    $soup_menu = array('Mozilla/3','Mozilla/2','Mozilla/1', 'Opera 4',
-                       'Opera/4', 'OmniWeb', 'Lynx');
-    sqgetGlobalVar('HTTP_USER_AGENT', $user_agent, SQ_SERVER);
-    foreach($soup_menu as $browser) {
-        if(stristr($user_agent, $browser)) {
-            return 1;
-        }
-    }
-    return 0;
+    return !checkForJavascript();
 }
+
+/**
+ * Check if plugin is enabled
+ * @param string $plugin_name plugin name
+ * @since 1.5.1
+ * @return boolean
+ */
+function is_plugin_enabled($plugin_name) {
+  global $plugins;
+
+  /**
+   * check if variable is empty. if var is not set, php empty 
+   * returns true without error notice.
+   *
+   * then check if it is an array
+   */
+  if (empty($plugins) || ! is_array($plugins))
+    return false;
+
+  if ( in_array($plugin_name,$plugins) ) {
+    return true;
+  } else {
+    return false;
+  }
+}
+
 /*************************************/
 /*** MAIN PLUGIN LOADING CODE HERE ***/
 /*************************************/
 
 /* On startup, register all plugins configured for use. */
 if (isset($plugins) && is_array($plugins)) {
+    // turn on output buffering in order to prevent output of new lines
+    ob_start();
     foreach ($plugins as $name) {
         use_plugin($name);
     }
+    // get output and remove whitespace
+    $output = trim(ob_get_contents());
+    ob_end_clean();
+    // if plugins output more than newlines and spacing, stop script execution.
+    if (!empty($output)) {
+        die($output);
+    }
 }
 
 ?>
