@@ -3,16 +3,18 @@
 /**
  * tree.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
+ * This file provides functions to walk trees of folders, for
+ * instance to delete a whole tree.
  *
- * This code provides various string manipulation functions that are
- * used by the rest of the Squirrelmail code.
- *
- * $Id: tree.php,v 1.28 2003/10/29 09:35:51 kink Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: tree.php,v 1.42 2006/02/05 11:29:41 tokul Exp $
  * @package squirrelmail
  */
 
+/** @ignore */
+if (! defined('SM_PATH')) define('SM_PATH','../');
+
 /** Clearly, this needs the IMAP functions.. */
 require_once(SM_PATH . 'functions/imap.php');
 
@@ -81,27 +83,40 @@ function addChildNodeToTree($comparisonValue, $value, &$tree) {
  */
 function walkTreeInPreOrderEmptyTrash($index, $imap_stream, $tree) {
     global $trash_folder;
+    walkTreeInPreOrderEmptyFolder($index, $imap_stream, $tree, $trash_folder);
+}
+
+/**
+ * Recursively walk the tree of mailboxes in the given folder and delete all folders and messages
+ *
+ * @param int index the place in the tree to start, usually 0
+ * @param stream imap_stream the IMAP connection to send commands to
+ * @param array tree the tree to walk
+ * @param mailbox the name of the root folder to empty
+ * @return void
+ */
+function walkTreeInPreOrderEmptyFolder($index, $imap_stream, $tree, $mailbox) {
     if ($tree[$index]['doIHaveChildren']) {
         for ($j = 0; $j < count($tree[$index]['subNodes']); $j++) {
             walkTreeInPreOrderEmptyTrash($tree[$index]['subNodes'][$j], $imap_stream, $tree);
         }
-        if ($tree[$index]['value'] != $trash_folder) {
+        if ($tree[$index]['value'] != $mailbox) {
             sqimap_mailbox_delete($imap_stream, $tree[$index]['value']);
         } else {
-            $mbx_response = sqimap_mailbox_select($imap_stream, $trash_folder);
+            $mbx_response = sqimap_mailbox_select($imap_stream, $mailbox);
             if ($mbx_response['EXISTS'] > 0) {
-               sqimap_messages_flag ($imap_stream, 1, '*', 'Deleted', true);
+                sqimap_toggle_flag($imap_stream, '1:*', '\\Deleted', true, true);
                // CLOSE === EXPUNGE and UNSELECT
                sqimap_run_command($imap_stream,'CLOSE',false,$response,$message);
             }
         }
     } else {
-        if ($tree[$index]['value'] != $trash_folder) {
+        if ($tree[$index]['value'] != $mailbox) {
             sqimap_mailbox_delete($imap_stream, $tree[$index]['value']);
         } else {
-            $mbx_response = sqimap_mailbox_select($imap_stream, $trash_folder);
+            $mbx_response = sqimap_mailbox_select($imap_stream, $mailbox);
             if ($mbx_response['EXISTS'] > 0) {
-                sqimap_messages_flag ($imap_stream, 1, '*', 'Deleted', true);
+                sqimap_toggle_flag($imap_stream, '1:*', '\\Deleted', true, true);
                 // CLOSE === EXPUNGE and UNSELECT
                 sqimap_run_command($imap_stream,'CLOSE',false,$response,$message);
             }
@@ -135,26 +150,33 @@ function walkTreeInPreOrderDeleteFolders($index, $imap_stream, $tree) {
 function walkTreeInPostOrderCreatingFoldersUnderTrash($index, $imap_stream, $tree, $topFolderName) {
     global $trash_folder, $delimiter;
 
-    $position = strrpos($topFolderName, $delimiter) + 1;
+    $position = strrpos($topFolderName, $delimiter);
+    if ($position !== FALSE) {
+        $position++;
+    }
     $subFolderName = substr($tree[$index]['value'], $position);
 
     if ($tree[$index]['doIHaveChildren']) {
-        sqimap_mailbox_create($imap_stream, $trash_folder . $delimiter . $subFolderName, "");
-        $mbx_response = sqimap_mailbox_select($imap_stream, $tree[$index]['value']);	    
+        // create new trash subfolder only if it does not exist.
+        if (!sqimap_mailbox_exists($imap_stream, $trash_folder . $delimiter . $subFolderName))
+            sqimap_mailbox_create($imap_stream, $trash_folder . $delimiter . $subFolderName, "");
+
+        $mbx_response = sqimap_mailbox_select($imap_stream, $tree[$index]['value']);
         $messageCount = $mbx_response['EXISTS'];
         if ($messageCount > 0) {
-            sqimap_messages_copy($imap_stream, 1, '*', $trash_folder . $delimiter . $subFolderName);
+            sqimap_msgs_list_copy($imap_stream, '1:*', $trash_folder . $delimiter . $subFolderName);
         }
         // after copy close the mailbox to get in unselected state
         sqimap_run_command($imap_stream,'CLOSE',false,$response,$message);
         for ($j = 0;$j < count($tree[$index]['subNodes']); $j++)
             walkTreeInPostOrderCreatingFoldersUnderTrash($tree[$index]['subNodes'][$j], $imap_stream, $tree, $topFolderName);
     } else {
-        sqimap_mailbox_create($imap_stream, $trash_folder . $delimiter . $subFolderName, '');
+        if (!sqimap_mailbox_exists($imap_stream, $trash_folder . $delimiter . $subFolderName))
+            sqimap_mailbox_create($imap_stream, $trash_folder . $delimiter . $subFolderName, '');
         $mbx_response = sqimap_mailbox_select($imap_stream, $tree[$index]['value']);
         $messageCount = $mbx_response['EXISTS'];
         if ($messageCount > 0) {
-            sqimap_messages_copy($imap_stream, 1, '*', $trash_folder . $delimiter . $subFolderName);
+            sqimap_msgs_list_copy($imap_stream, '1:*', $trash_folder . $delimiter . $subFolderName);
         }
         // after copy close the mailbox to get in unselected state
         sqimap_run_command($imap_stream,'CLOSE',false,$response,$message);
@@ -172,9 +194,10 @@ function simpleWalkTreePre($index, $tree) {
         for ($j = 0; $j < count($tree[$index]['subNodes']); $j++) {
             simpleWalkTreePre($tree[$index]['subNodes'][$j], $tree);
         }
-        echo $tree[$index]['value'] . '<br>';
+        echo $tree[$index]['value'] . '<br />';
     } else {
-        echo $tree[$index]['value'] . '<br>';
+        echo $tree[$index]['value'] . '<br />';
     }
 }
-?>
+
+?>
\ No newline at end of file
