@@ -3,13 +3,12 @@
 /**
  * url_parser.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This code provides various string manipulation functions that are
- * used by the rest of the Squirrelmail code.
+ * used by the rest of the SquirrelMail code.
  *
- * $Id: url_parser.php,v 1.49 2003/11/30 17:01:44 alex-brainstorm Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: url_parser.php,v 1.62 2006/01/23 18:39:33 tokul Exp $
  * @package squirrelmail
  */
 
@@ -26,6 +25,10 @@ function replaceBlock (&$in, $replace, $start, $end) {
  * to be made to the pattern
  * Make sure that the expression is evaluated case insensitively
  *
+ * RFC2822 (and RFC822) defines the left side of an email address as (roughly):
+ *  1*atext *("." 1*atext)
+ * where atext is: a-zA-Z0-9!#$%&'*+-/=?^_`{|}~
+ *
  * Here's pretty sophisticated IP matching:
  * $IPMatch = '(2[0-5][0-9]|1?[0-9]{1,2})';
  * $IPMatch = '\[?' . $IPMatch . '(\.' . $IPMatch . '){3}\]?';
@@ -35,8 +38,10 @@ global $IP_RegExp_Match, $Host_RegExp_Match, $Email_RegExp_Match;
 $IP_RegExp_Match = '\\[?[0-9]{1,3}(\\.[0-9]{1,3}){3}\\]?';
 $Host_RegExp_Match = '(' . $IP_RegExp_Match .
     '|[0-9a-z]([-.]?[0-9a-z])*\\.[a-z][a-z]+)';
-$Email_RegExp_Match = '[0-9a-z]([-_.+]?[0-9a-z])*(%' . $Host_RegExp_Match .
-    ')?@' . $Host_RegExp_Match;
+$atext = '([a-z0-9!#$&%*+/=?^_`{|}~-]|&amp;)';
+$dot_atom = $atext . '+(\.' . $atext . '+)*';
+$Email_RegExp_Match = $dot_atom . '(%' . $Host_RegExp_Match . ')?@' .
+                      $Host_RegExp_Match;
 
 /**
  * Parses a body and converts all found email addresses to clickable links.
@@ -45,21 +50,23 @@ $Email_RegExp_Match = '[0-9a-z]([-_.+]?[0-9a-z])*(%' . $Host_RegExp_Match .
  * @return int the number of unique addresses found
  */
 function parseEmail (&$body) {
-    global $color, $Email_RegExp_Match;
+    global $Email_RegExp_Match;
     $sbody     = $body;
     $addresses = array();
 
     /* Find all the email addresses in the body */
     while(eregi($Email_RegExp_Match, $sbody, $regs)) {
-        $addresses[$regs[0]] = $regs[0];
+        $addresses[$regs[0]] = strtr($regs[0], array('&amp;' => '&'));
         $start = strpos($sbody, $regs[0]) + strlen($regs[0]);
         $sbody = substr($sbody, $start);
     }
+
     /* Replace each email address with a compose URL */
-    foreach ($addresses as $email) {
-        $comp_uri = makeComposeLink('src/compose.php?send_to='.urlencode($email), $email);
-        $body = str_replace($email, $comp_uri, $body);
+    foreach ($addresses as $text => $email) {
+        $comp_uri = makeComposeLink('src/compose.php?send_to='.urlencode($email), $text);
+        $body = str_replace($text, $comp_uri, $body);
     }
+
     /* Return number of unique addresses found */
     return count($addresses);
 }
@@ -79,8 +86,8 @@ $url_parser_url_tokens = array(
     'news://');
 
 global $url_parser_poss_ends;
-$url_parser_poss_ends = array(' ', "\n", "\r", '<', '>', ".\r", ".\n", 
-    '.&nbsp;', '&nbsp;', ')', '(', '&quot;', '&lt;', '&gt;', '.<', 
+$url_parser_poss_ends = array(' ', "\n", "\r", '<', '>', ".\r", ".\n",
+    '.&nbsp;', '&nbsp;', ')', '(', '&quot;', '&lt;', '&gt;', '.<',
     ']', '[', '{', '}', "\240", ', ', '. ', ",\n", ",\r");
 
 
@@ -111,7 +118,7 @@ function parseUrl (&$body) {
         /* Find the first token to replace */
         foreach ($url_parser_url_tokens as $the_token) {
             $pos = strpos(strtolower($body), $the_token, $start);
-            if (is_int($pos) && $pos < $blength) {
+            if (is_int($pos) && $pos < $target_pos) {
                 $target_pos   = $pos;
                 $target_token = $the_token;
             }
@@ -127,8 +134,8 @@ function parseUrl (&$body) {
         }
 
         /* If there was a token to replace, replace it */
-        if ($target_token == 'mailto:') {	// rfc 2368 (mailto URL)
-            $target_pos += 7;	//skip mailto:
+        if ($target_token == 'mailto:') {    // rfc 2368 (mailto URL)
+            $target_pos += 7;    //skip mailto:
             $end = $blength;
 
             $mailto = substr($body, $target_pos, $end-$target_pos);
@@ -138,18 +145,18 @@ function parseUrl (&$body) {
                 //sm_print_r($regs);
                 $mailto_before = $target_token . $regs[0];
                 $mailto_params = $regs[10];
-                if ($regs[1]) {	//if there is an email addr before '?', we need to merge it with the params
+                if ($regs[1]) {    //if there is an email addr before '?', we need to merge it with the params
                     $to = 'to=' . $regs[1];
-                    if (strpos($mailto_params, 'to=') > -1)	//already a 'to='
+                    if (strpos($mailto_params, 'to=') > -1)    //already a 'to='
                         $mailto_params = str_replace('to=', $to . '%2C%20', $mailto_params);
                     else {
-                        if ($mailto_params)	//already some params, append to them
+                        if ($mailto_params)    //already some params, append to them
                             $mailto_params .= '&amp;' . $to;
                         else
                             $mailto_params .= '?' . $to;
                     }
                 }
-                $url_str = str_replace(array('to=', 'cc=', 'bcc='), array('send_to=', 'send_to_cc=', 'send_to_bcc='), $mailto_params);
+                $url_str = preg_replace(array('/to=/i', '/(?<!b)cc=/i', '/bcc=/i'), array('send_to=', 'send_to_cc=', 'send_to_bcc='), $mailto_params);
                 $comp_uri = makeComposeLink('src/compose.php' . $url_str, $mailto_before);
                 replaceBlock($body, $comp_uri, $target_pos - 7, $target_pos + strlen($regs[0]));
                 $target_pos += strlen($comp_uri) - 7;
@@ -191,5 +198,28 @@ function parseUrl (&$body) {
         $start   = $target_pos;
         $blength = strlen($body);
     }
-} 
-?>
+}
+
+/**
+ * Parses a string and returns the first e-mail address found.
+ *
+ * @param string string the string to process
+ * @return string the first e-mail address found
+ */
+function getEmail($string) {
+    global $Email_RegExp_Match;
+    $addresses = array();
+
+    /* Find all the email addresses in the body */
+    while (eregi($Email_RegExp_Match, $string, $regs)) {
+        $addresses[$regs[0]] = strtr($regs[0], array('&amp;' => '&'));
+        $start = strpos($string, $regs[0]) + strlen($regs[0]);
+        $string = substr($string, $start);
+    }
+
+    /* Return the first address, or an empty string if no address was found */
+    $addresses = array_values($addresses);
+    return (array_key_exists(0, $addresses) ? $addresses[0] : '');
+}
+
+?>
\ No newline at end of file
