@@ -3,12 +3,11 @@
 /**
  * options_display.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * Displays all optinos about display preferences
  *
- * $Id: display.php,v 1.19 2004/01/28 04:10:26 ebullient Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: display.php,v 1.55 2006/02/12 09:08:11 tokul Exp $
  * @package squirrelmail
  */
 
@@ -17,6 +16,25 @@ define('SMOPT_GRP_GENERAL', 0);
 define('SMOPT_GRP_MAILBOX', 1);
 define('SMOPT_GRP_MESSAGE', 2);
 
+// load icon themes if in use
+global $use_icons;
+if ($use_icons) {
+    global $icon_themes;
+    $dirName = SM_PATH . 'images/themes';
+    if (is_readable($dirName) && is_dir($dirName)) {
+        $d = dir($dirName);
+        while($dir = $d->read()) {
+            if ($dir != "." && $dir != "..") {
+                if (is_dir($dirName."/".$dir) && file_exists("$dirName/$dir/theme.php"))
+                    include("$dirName/$dir/theme.php");
+            }
+        }
+    }
+}
+
+global $use_iframe;
+if (! isset($use_iframe)) $use_iframe=false;
+
 /**
  * This function builds an array with all the information about
  * the options available to the user, and returns it. The options
@@ -31,9 +49,9 @@ define('SMOPT_GRP_MESSAGE', 2);
  * @return array all option information
  */
 function load_optpage_data_display() {
-    global $theme, $language, $languages, $js_autodetect_results,
-    $compose_new_win, $default_use_mdn, $squirrelmail_language, $allow_thread_sort,
-    $optmode, $show_alternative_names, $available_languages;
+    global $theme, $fontsets, $language, $languages,$aTemplateSet,
+    $default_use_mdn, $squirrelmail_language, $allow_thread_sort,
+    $show_alternative_names, $use_icons, $use_iframe, $sTplDir;
 
     /* Build a simple array into which we will build options. */
     $optgrps = array();
@@ -47,6 +65,26 @@ function load_optpage_data_display() {
     $optgrps[SMOPT_GRP_GENERAL] = _("General Display Options");
     $optvals[SMOPT_GRP_GENERAL] = array();
 
+    /* load the template set option */
+    $templateset_values = array();
+
+    foreach ($aTemplateSet as $sKey => $aTemplateSetAttributes) {
+        $templateset_values[$aTemplateSetAttributes['NAME']] = $aTemplateSetAttributes['PATH'];
+    }
+    ksort($templateset_values);
+    $templateset_values = array_flip($templateset_values);
+    // display template options only when there is more than one template
+    if (count($templateset_values)>1) {
+        $optvals[SMOPT_GRP_GENERAL][] = array(
+            'name'    => 'sTplDir',
+            'caption' => _("Template"),
+            'type'    => SMOPT_TYPE_STRLIST,
+            'refresh' => SMOPT_REFRESH_ALL,
+            'posvals' => $templateset_values,
+            'save'    => 'save_option_template'
+        );
+    }
+
     /* Load the theme option. */
     $theme_values = array();
     foreach ($theme as $theme_key => $theme_attributes) {
@@ -62,18 +100,22 @@ function load_optpage_data_display() {
         'posvals' => $theme_values,
         'save'    => 'save_option_theme'
     );
- 
+
     $css_values = array( 'none' => _("Default" ) );
-    $handle=opendir('../themes/css/');
-    while ($file = readdir($handle) ) {
-        if ( substr( $file, -4 ) == '.css' ) {
-            $css_values[$file] = substr( $file, 0, strlen( $file ) - 4 );
+    $css_dir = SM_PATH . 'themes/css';
+    if (is_readable($css_dir) && is_dir($css_dir)) {
+        $handle=opendir($css_dir);
+        while ($file = readdir($handle) ) {
+            if ( substr( $file, -4 ) == '.css' ) {
+                $css_values[$file] = substr( $file, 0, strlen( $file ) - 4 );
+            }
         }
+        closedir($handle);
     }
-    closedir($handle);
-    
+
+    /*
     if ( count( $css_values ) > 1 ) {
-    
+
         $optvals[SMOPT_GRP_GENERAL][] = array(
             'name'    => 'custom_css',
             'caption' => _("Custom Stylesheet"),
@@ -81,52 +123,67 @@ function load_optpage_data_display() {
             'refresh' => SMOPT_REFRESH_ALL,
             'posvals' => $css_values
         );
-    
+
+    }
+    */
+
+    $fontset_values = array();
+    foreach (array_keys($fontsets) as $fontset_key) {
+        $fontset_list[$fontset_key]=$fontset_key;
+    }
+    ksort($fontset_list);
+
+    if (count($fontset_list) > 1) {
+        $fontset_list = array_merge(array('' => _("Default font style")), $fontset_list);
+        $optvals[SMOPT_GRP_GENERAL][] = array(
+            'name'    => 'chosen_fontset',
+            'caption' => _("Font style"),
+            'type'    => SMOPT_TYPE_STRLIST,
+            'refresh' => SMOPT_REFRESH_ALL,
+            'posvals' => $fontset_list
+        );
     }
 
-    // config.php can be unupdated.
-    if (! isset($available_languages) || $available_languages=="" ) {
-     $available_languages="ALL"; }
-    
+    $optvals[SMOPT_GRP_GENERAL][] = array(
+        'name'    => 'chosen_fontsize',
+        'caption' => _("Font size"),
+        'type'    => SMOPT_TYPE_STRLIST,
+        'refresh' => SMOPT_REFRESH_ALL,
+        'posvals' => array('' => _("Default font size"),
+                           '8' => '8 px',
+                           '10' => '10 px',
+                           '12' => '12 px',
+                           '14' => '14 px')
+    );
+
     $language_values = array();
-    if ( strtoupper($available_languages)=='ALL') {
-	foreach ($languages as $lang_key => $lang_attributes) {
-    	    if (isset($lang_attributes['NAME'])) {
-        	$language_values[$lang_key] = $lang_attributes['NAME'];
-		if ( isset($show_alternative_names) &&
-		  $show_alternative_names &&
-		  isset($lang_attributes['ALTNAME']) ) {
-		    $language_values[$lang_key] .= " / " . $lang_attributes['ALTNAME'];
-		}
-    	    }
-	}
-    } else if (strtoupper($available_languages)!='NONE') {
-	// admin can set list of available languages in config
-	$available_languages_array=explode (" ",$available_languages);
-        foreach ($available_languages_array as $lang_key ) {
-    	    if (isset($languages[$lang_key]['NAME'])) {
-        	$language_values[$lang_key] = $languages[$lang_key]['NAME'];
-    		if ( isset($show_alternative_names) &&
-		 $show_alternative_names &&
-		 isset($languages[$lang_key]['ALTNAME']) ) {
-    		    $language_values[$lang_key] .= " / " . $languages[$lang_key]['ALTNAME'];
-        	}
-    	    }	    
-	}
+    foreach ($languages as $lang_key => $lang_attributes) {
+        if (isset($lang_attributes['NAME'])) {
+            $language_values[$lang_key] = $lang_attributes['NAME'];
+            if ( isset($show_alternative_names) &&
+                 $show_alternative_names &&
+                 isset($lang_attributes['ALTNAME']) ) {
+                $language_values[$lang_key] .= " / " . $lang_attributes['ALTNAME'];
+            }
+        }
     }
+
     asort($language_values);
     $language_values =
         array_merge(array('' => _("Default")), $language_values);
     $language = $squirrelmail_language;
-    if (strtoupper($available_languages)!='NONE') {
-	// if set to 'none', interface will use only default language
-	$optvals[SMOPT_GRP_GENERAL][] = array(
-    	    'name'    => 'language',
-    	    'caption' => _("Language"),
-    	    'type'    => SMOPT_TYPE_STRLIST,
-    	    'refresh' => SMOPT_REFRESH_ALL,
-    	    'posvals' => $language_values
-	);
+
+    // add language selection only when more than 2 languages are available
+    // (default, English and some other)
+    if (count($language_values)>2) {
+        $optvals[SMOPT_GRP_GENERAL][] = array(
+            'name'    => 'language',
+            'caption' => _("Language"),
+            'type'    => SMOPT_TYPE_STRLIST,
+            'refresh' => SMOPT_REFRESH_ALL,
+            'posvals' => $language_values,
+            'htmlencoded' => true
+        );
     }
 
     /* Set values for the "use javascript" option. */
@@ -137,22 +194,26 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_ALL,
         'posvals' => array(SMPREF_JS_AUTODETECT => _("Autodetect"),
                            SMPREF_JS_ON         => _("Always"),
-                           SMPREF_JS_OFF        => _("Never"))
+                           SMPREF_JS_OFF        => _("Never")),
+        'save'    => 'save_option_javascript_autodetect',
+        'script'  => 'onclick="document.forms[0].new_js_autodetect_results.value = \'' . SMPREF_JS_ON . '\';"'
     );
 
-
-    if ($optmode != 'submit')
-       $onLoadScript = 'document.forms[0].new_js_autodetect_results.value = \'' . SMPREF_JS_ON . '\'';
-    else
-       $onLoadScript = '';
-
     $optvals[SMOPT_GRP_GENERAL][] = array(
         'name'    => 'js_autodetect_results',
         'caption' => '',
         'type'    => SMOPT_TYPE_HIDDEN,
-        'refresh' => SMOPT_REFRESH_NONE,
+        'refresh' => SMOPT_REFRESH_NONE
         //'post_script' => $js_autodetect_script,
-        'save'    => 'save_option_javascript_autodetect'
+    );
+
+    $optvals[SMOPT_GRP_GENERAL][] = array(
+        'name'    => 'hour_format',
+        'caption' => _("Hour Format"),
+        'type'    => SMOPT_TYPE_STRLIST,
+        'refresh' => SMOPT_REFRESH_FOLDERLIST,
+        'posvals' => array(SMPREF_TIME_12HR => _("12-hour clock"),
+                           SMPREF_TIME_24HR => _("24-hour clock"))
     );
 
     /*** Load the General Options into the array ***/
@@ -161,7 +222,7 @@ function load_optpage_data_display() {
 
     $optvals[SMOPT_GRP_MAILBOX][] = array(
         'name'    => 'show_num',
-        'caption' => _("Number of Messages to Index"),
+        'caption' => _("Number of Messages per Page"),
         'type'    => SMOPT_TYPE_INTEGER,
         'refresh' => SMOPT_REFRESH_NONE,
         'size'    => SMOPT_SIZE_TINY
@@ -174,6 +235,41 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_NONE
     );
 
+    $optvals[SMOPT_GRP_MAILBOX][] = array(
+        'name'    => 'fancy_index_highlite',
+        'caption' => _("Enable Fancy Row Mouseover Highlighting"),
+        'type'    => SMOPT_TYPE_BOOLEAN,
+        'refresh' => SMOPT_REFRESH_NONE
+    );
+
+    if ($use_icons) {
+        global $icon_themes, $icon_theme;
+        $temp = array();
+        for ($count = 0; $count < sizeof($icon_themes); $count++) {
+            $temp[$count] = $icon_themes[$count]['NAME'];
+            if ($icon_theme == $icon_themes[$count]['PATH'])
+                $value = $count;
+        }
+        if (sizeof($icon_themes) > 0) {
+            $optvals[SMOPT_GRP_MAILBOX][] = array(
+                'name'          => 'icon_theme',
+                'caption'       => _("Message Flags Icon Theme"),
+                'type'          => SMOPT_TYPE_STRLIST,
+                'refresh'       => SMOPT_REFRESH_NONE,
+                'posvals'       => $temp,
+                'initial_value' => $value,
+                'save'          => 'icon_theme_save'
+            );
+        }
+    }
+
+    $optvals[SMOPT_GRP_MAILBOX][] = array(
+        'name'    => 'show_flag_buttons',
+        'caption' => _("Show Flag / Unflag Buttons"),
+        'type'    => SMOPT_TYPE_BOOLEAN,
+        'refresh' => SMOPT_REFRESH_NONE
+    );
+
     $optvals[SMOPT_GRP_MAILBOX][] = array(
         'name'    => 'page_selector',
         'caption' => _("Enable Page Selector"),
@@ -181,6 +277,13 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_NONE
     );
 
+    $optvals[SMOPT_GRP_MAILBOX][] = array(
+        'name'    => 'compact_paginator',
+        'caption' => _("Use Compact Page Selector"),
+        'type'    => SMOPT_TYPE_BOOLEAN,
+        'refresh' => SMOPT_REFRESH_NONE
+    );
+
     $optvals[SMOPT_GRP_MAILBOX][] = array(
         'name'    => 'page_selector_max',
         'caption' => _("Maximum Number of Pages to Show"),
@@ -211,7 +314,8 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_NONE,
         'size'    => SMOPT_SIZE_TINY
     );
-
+/*
+  disabled because the template doesn't support it (yet?)
     $optvals[SMOPT_GRP_MAILBOX][] = array(
         'name'    => 'show_recipient_instead',
         'caption' => _("Show recipient name if the message is from your default identity"),
@@ -219,10 +323,21 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_NONE,
         'size'    => SMOPT_SIZE_TINY
     );
+*/
+
+    if ($allow_thread_sort == TRUE) {
+        $optvals[SMOPT_GRP_MAILBOX][] = array(
+            'name'    => 'sort_by_ref',
+            'caption' => _("Enable Thread Sort by References Header"),
+            'type'    => SMOPT_TYPE_BOOLEAN,
+            'refresh' => SMOPT_REFRESH_ALL
+        );
+    }
+
 
 
     /*** Load the General Options into the array ***/
-    $optgrps[SMOPT_GRP_MESSAGE] = _("Message Display and Composition");
+    $optgrps[SMOPT_GRP_MESSAGE] = _("Message Display Options");
     $optvals[SMOPT_GRP_MESSAGE] = array();
 
     $optvals[SMOPT_GRP_MESSAGE][] = array(
@@ -233,34 +348,6 @@ function load_optpage_data_display() {
         'size'    => SMOPT_SIZE_TINY
     );
 
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'editor_size',
-        'caption' => _("Size of Editor Window"),
-        'type'    => SMOPT_TYPE_INTEGER,
-        'refresh' => SMOPT_REFRESH_NONE,
-        'size'    => SMOPT_SIZE_TINY
-    );
-
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'location_of_buttons',
-        'caption' => _("Location of Buttons when Composing"),
-        'type'    => SMOPT_TYPE_STRLIST,
-        'refresh' => SMOPT_REFRESH_NONE,
-        'posvals' => array(SMPREF_LOC_TOP     => _("Before headers"),
-                           SMPREF_LOC_BETWEEN => _("Between headers and message body"),
-                           SMPREF_LOC_BOTTOM  => _("After message body"))
-    );
-
-
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'use_javascript_addr_book',
-        'caption' => _("Addressbook Display Format"),
-        'type'    => SMOPT_TYPE_STRLIST,
-        'refresh' => SMOPT_REFRESH_NONE,
-        'posvals' => array('1' => _("Javascript"),
-                           '0' => _("HTML"))
-    );
-
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'show_html_default',
         'caption' => _("Show HTML Version by Default"),
@@ -268,6 +355,16 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_NONE
     );
 
+    if ($use_iframe) {
+        // Type is set to string in order to be able to use 100%.
+        $optvals[SMOPT_GRP_MESSAGE][] = array(
+            'name'    => 'iframe_height',
+            'caption' => _("Height of inline frame"),
+            'type'    => SMOPT_TYPE_STRING,
+            'size'    => SMOPT_SIZE_TINY,
+            'refresh' => SMOPT_REFRESH_NONE
+        );
+    }
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'enable_forward_as_attachment',
         'caption' => _("Enable Forward as Attachment"),
@@ -275,20 +372,6 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_NONE
     );
 
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'forward_cc',
-        'caption' => _("Include CCs when Forwarding Messages"),
-        'type'    => SMOPT_TYPE_BOOLEAN,
-        'refresh' => SMOPT_REFRESH_NONE
-    );
-
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'include_self_reply_all',
-        'caption' => _("Include Me in CC when I Reply All"),
-        'type'    => SMOPT_TYPE_BOOLEAN,
-        'refresh' => SMOPT_REFRESH_NONE
-    );
-
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'show_xmailer_default',
         'caption' => _("Enable Mailer Display"),
@@ -303,13 +386,6 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_NONE
     );
 
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'pf_cleandisplay',
-        'caption' => _("Enable Printer Friendly Clean Display"),
-        'type'    => SMOPT_TYPE_BOOLEAN,
-        'refresh' => SMOPT_REFRESH_NONE
-    );
-
     if ($default_use_mdn) {
         $optvals[SMOPT_GRP_MESSAGE][] = array(
             'name'    => 'mdn_user_support',
@@ -319,79 +395,17 @@ function load_optpage_data_display() {
         );
     }
 
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'compose_new_win',
-        'caption' => _("Compose Messages in New Window"),
-        'type'    => SMOPT_TYPE_BOOLEAN,
-        'refresh' => SMOPT_REFRESH_ALL
-    );
-
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'compose_width',
-        'caption' => _("Width of Compose Window"),
-        'type'    => SMOPT_TYPE_INTEGER,
-        'refresh' => SMOPT_REFRESH_ALL,
-        'size'    => SMOPT_SIZE_TINY
-    );
-
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'compose_height',
-        'caption' => _("Height of Compose Window"),
-        'type'    => SMOPT_TYPE_INTEGER,
-        'refresh' => SMOPT_REFRESH_ALL,
-        'size'    => SMOPT_SIZE_TINY
-    );
-
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'sig_first',
-        'caption' => _("Append Signature before Reply/Forward Text"),
-        'type'    => SMOPT_TYPE_BOOLEAN,
-        'refresh' => SMOPT_REFRESH_NONE
-    );
-
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'reply_focus',
-        'caption' => _("Cursor Position when Replying"),
-        'type'    => SMOPT_TYPE_STRLIST,
-        'refresh' => SMOPT_REFRESH_NONE,
-        'posvals' => array('' => _("To: field"),
-                           'focus' => _("Focus in body"),
-                           'select' => _("Select body"))
-    );
-
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'strip_sigs',
-        'caption' => _("Strip signature when replying"),
-        'type'    => SMOPT_TYPE_BOOLEAN,
-        'refresh' => SMOPT_REFRESH_NONE
-    );
-
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'internal_date_sort',
-        'caption' => _("Enable Sort by of Receive Date"),
-        'type'    => SMOPT_TYPE_BOOLEAN,
-        'refresh' => SMOPT_REFRESH_ALL
-    );
-    if ($allow_thread_sort == TRUE) {
-        $optvals[SMOPT_GRP_MESSAGE][] = array(
-            'name'    => 'sort_by_ref',
-            'caption' => _("Enable Thread Sort by References Header"),
-            'type'    => SMOPT_TYPE_BOOLEAN,
-            'refresh' => SMOPT_REFRESH_ALL
-        );
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'delete_prev_next_display',
         'caption' => _("Show 'Delete & Prev/Next' Links"),
         'type'    => SMOPT_TYPE_BOOLEAN,
         'refresh' => SMOPT_REFRESH_ALL
     );
-        
-    }
+
     /* Assemble all this together and return it as our result. */
     $result = array(
         'grps' => $optgrps,
-        'vals' => $optvals,
-        'xtra' => $onLoadScript
+        'vals' => $optvals
     );
     return ($result);
 }
@@ -400,6 +414,29 @@ function load_optpage_data_display() {
 /** Define any specialized save functions for this option page. ***/
 /******************************************************************/
 
+/**
+ * This function saves a new template setting.
+ * It updates the template array.
+ */
+function save_option_template($option) {
+    global $aTemplateSet;
+
+    /* Do checking to make sure $new_theme is in the array. */
+    $templateset_in_array = false;
+    for ($i = 0; $i < count($aTemplateSet); ++$i) {
+        if ($aTemplateSet[$i]['PATH'] == $option->new_value) {
+            $templateset_in_array = true;
+            break;
+        }
+    }
+
+    if (!$templateset_in_array) {
+        $option->new_value = '';
+    }
+    /* Save the option like normal. */
+    save_option($option);
+}
+
 /**
  * This function saves a new theme setting.
  * It updates the theme array.
@@ -428,18 +465,26 @@ function save_option_theme($option) {
  * This function saves the javascript detection option.
  */
 function save_option_javascript_autodetect($option) {
-    global $data_dir, $username, $new_javascript_setting;
-
-    /* Set javascript either on or off. */
-    if ($new_javascript_setting == SMPREF_JS_AUTODETECT) {
-        if ($option->new_value == SMPREF_JS_ON) {
-            setPref($data_dir, $username, 'javascript_on', SMPREF_JS_ON);
-        } else {
-            setPref($data_dir, $username, 'javascript_on', SMPREF_JS_OFF);
-        }
-    } else {
-        setPref($data_dir, $username, 'javascript_on', $new_javascript_setting);
-    }
+    save_option($option);
+    checkForJavascript(TRUE);
 }
 
-?>
+/**
+ * This function saves the user's icon theme setting
+ */
+function icon_theme_save($option) {
+
+    global $icon_themes, $data_dir, $username;
+
+
+    // Don't assume the new value is there, double check
+    // and only save if found
+    //
+    if (isset($icon_themes[$option->new_value]['PATH']))
+        setPref($data_dir, $username, 'icon_theme', $icon_themes[$option->new_value]['PATH']);
+    else
+       setPref($data_dir, $username, 'icon_theme', 'none');
+
+}
+
+?>
\ No newline at end of file
