@@ -1,20 +1,24 @@
 <?php
 
 /**
- * Administrator Plugin
+ * Administrator Plugin - Options Page
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
+ * This script creates separate page, that allows to review and modify
+ * SquirrelMail configuration file.
  *
- * Philippe Mingo
- *
- * $Id: options.php,v 1.36 2003/12/01 21:56:48 cigamit Exp $
+ * @author Philippe Mingo
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: options.php,v 1.54 2006/02/09 19:38:50 tokul Exp $
  * @package plugins
  * @subpackage administrator
  */
 
 /**
  * parse the config file
+ *
+ * @param string $cfg_file
+ * @access private
  */
 function parseConfig( $cfg_file ) {
 
@@ -24,6 +28,7 @@ function parseConfig( $cfg_file ) {
     $mode = '';
     $l = count( $cfg );
     $modifier = FALSE;
+    $arraykey = 0;
 
     for ($i=0;$i<$l;$i++) {
         $line = trim( $cfg[$i] );
@@ -41,10 +46,15 @@ function parseConfig( $cfg_file ) {
                 break;
             case 'K':
                 // Key detect
-                if( $line{$j} == ' ' ) {
+                if ( $line{$j} == ' ' ) {
                     $mode = '=';
                 } else {
                     $key .= $line{$j};
+                    // FIXME: this is only pour workaround for plugins[] array.
+                    if ($line{$j}=='[' && $line{($j+1)}==']') {
+                        $key .= $arraykey;
+                        $arraykey++;
+                    }
                 }
                 break;
             case ';':
@@ -134,67 +144,77 @@ function parseConfig( $cfg_file ) {
     }
 }
 
-/* Change paths containing SM_PATH to admin-friendly paths
-   relative to the config dir, i.e.:
-     ''                          --> <empty string>
-     SM_PATH . 'images/logo.gif' --> ../images/logo.gif
-     '/absolute/path/logo.gif'   --> /absolute/path/logo.gif
-     'http://whatever/'          --> http://whatever
-   Note removal of quotes in returned value
-*/
+/**
+ * Change paths containing SM_PATH to admin-friendly paths
+ * relative to the config dir, i.e.:
+ *    ''                          --> <empty string>
+ *    SM_PATH . 'images/logo.gif' --> ../images/logo.gif
+ *    '/absolute/path/logo.gif'   --> /absolute/path/logo.gif
+ *    'http://whatever/'          --> http://whatever
+ *  Note removal of quotes in returned value
+ *
+ * @param string $old_path path that has to be converted
+ * @return string new path
+ * @access private
+ */
 function change_to_rel_path($old_path) {
-    $new_path = str_replace("SM_PATH . '", "../", $old_path); 
+    $new_path = str_replace("SM_PATH . '", "../", $old_path);
     $new_path = str_replace("../config/","", $new_path);
     $new_path = str_replace("'","", $new_path);
     return $new_path;
 }
 
-/* Change relative path (relative to config dir) to 
-   internal SM_PATH, i.e.:
-     empty_string            --> ''
-     ../images/logo.gif      --> SM_PATH . 'images/logo.gif'
-     images/logo.gif         --> SM_PATH . 'config/images/logo.gif'
-     /absolute/path/logo.gif --> '/absolute/path/logo.gif'
-     http://whatever/        --> 'http://whatever'
-*/     
+/**
+ * Change relative path (relative to config dir) to
+ *  internal SM_PATH, i.e.:
+ *     empty_string            --> ''
+ *     ../images/logo.gif      --> SM_PATH . 'images/logo.gif'
+ *     images/logo.gif         --> SM_PATH . 'config/images/logo.gif'
+ *     /absolute/path/logo.gif --> '/absolute/path/logo.gif'
+ *     http://whatever/        --> 'http://whatever'
+ *
+ * @param string $old_path path that has to be converted
+ * @return string new path
+ * @access private
+*/
 function change_to_sm_path($old_path) {
-   if ( $old_path === '' || $old_path == "''" ) {
-     return "''";
-   } elseif ( preg_match("/^(\/|http)/", $old_path) ) {
-     return "'" . $old_path . "'";
-   } elseif ( preg_match("/^(\$|SM_PATH)/", $old_path) ) {
-     return $old_path;
-   }
-   
-   $new_path = '';
-   $rel_path = explode("../", $old_path);
-   if ( count($rel_path) > 2 ) {
-     // Since we're relative to the config dir, 
-     // more than 1 ../ puts us OUTSIDE the SM tree.
-     // get full path to config.php, then pop the filename
-     $abs_path = explode('/', realpath (SM_PATH . 'config/config.php'));
-     array_pop ($abs_path); 
-     foreach ( $rel_path as $subdir ) {
-       if ( $subdir === '' ) {
-         array_pop ($abs_path);
-       } else {
-         array_push($abs_path, $subdir);
-       }
-     }
-     foreach ($abs_path as $subdir) {
-       $new_path .= $subdir . '/';
-     }
-     $new_path = "'$new_path'";
-   } elseif ( count($rel_path) > 1 ) {
-     // we're within the SM tree, prepend SM_PATH
-     $new_path = str_replace('../',"SM_PATH . '", $old_path . "'");
-   } else {
-     // Last, if it's a relative path without a .. prefix, 
-     // we're somewhere within the config dir, so prepend
-     //  SM_PATH . 'config/  
-     $new_path = "SM_PATH . 'config/" . $old_path . "'";
-   }
-   return $new_path;
+    if ( $old_path === '' || $old_path == "''" ) {
+        return "''";
+    } elseif ( preg_match("/^(\/|http)/", $old_path) ) {
+        return "'" . $old_path . "'";
+    } elseif ( preg_match("/^(\$|SM_PATH)/", $old_path) ) {
+        return $old_path;
+    }
+
+    $new_path = '';
+    $rel_path = explode("../", $old_path);
+    if ( count($rel_path) > 2 ) {
+        // Since we're relative to the config dir,
+        // more than 1 ../ puts us OUTSIDE the SM tree.
+        // get full path to config.php, then pop the filename
+        $abs_path = explode('/', realpath (SM_PATH . 'config/config.php'));
+        array_pop ($abs_path);
+        foreach ( $rel_path as $subdir ) {
+            if ( $subdir === '' ) {
+                array_pop ($abs_path);
+            } else {
+                array_push($abs_path, $subdir);
+            }
+        }
+        foreach ($abs_path as $subdir) {
+            $new_path .= $subdir . '/';
+        }
+        $new_path = "'$new_path'";
+    } elseif ( count($rel_path) > 1 ) {
+        // we're within the SM tree, prepend SM_PATH
+        $new_path = str_replace('../',"SM_PATH . '", $old_path . "'");
+    } else {
+        // Last, if it's a relative path without a .. prefix,
+        // we're somewhere within the config dir, so prepend
+        //  SM_PATH . 'config/
+        $new_path = "SM_PATH . 'config/" . $old_path . "'";
+    }
+    return $new_path;
 }
 
 
@@ -205,13 +225,11 @@ define('SM_PATH','../../');
 
 /* SquirrelMail required files. */
 require_once(SM_PATH . 'include/validate.php');
-require_once(SM_PATH . 'functions/page_header.php');
 require_once(SM_PATH . 'functions/imap.php');
-require_once(SM_PATH . 'include/load_prefs.php');
 require_once(SM_PATH . 'plugins/administrator/defines.php');
 require_once(SM_PATH . 'plugins/administrator/auth.php');
 
-GLOBAL $data_dir, $username;
+global $data_dir, $username;
 
 if ( !adm_check_user() ) {
     header('Location: ' . SM_PATH . 'src/options.php') ;
@@ -240,29 +258,29 @@ $colapse = array( 'Titles' => 'off',
                   'Group7' => getPref($data_dir, $username, 'adm_Group7', 'on' ),
                   'Group8' => getPref($data_dir, $username, 'adm_Group8', 'on' ),
                   'Group9' => getPref($data_dir, $username, 'adm_Group9', 'on' ),
-                  'Group10' => getPref($data_dir, $username, 'adm_Group10', 'on' ) );
+                  'Group10' => getPref($data_dir, $username, 'adm_Group10', 'on' ),
+                  'Group11' => getPref($data_dir, $username, 'adm_Group11', 'on' ) );
 
 /* look in $_GET array for 'switch' */
 if ( sqgetGlobalVar('switch', $switch, SQ_GET) ) {
     if ( $colapse[$switch] == 'on' ) {
-       $colapse[$switch] = 'off';
+        $colapse[$switch] = 'off';
     } else {
-       $colapse[$switch] = 'on';
+        $colapse[$switch] = 'on';
     }
     setPref($data_dir, $username, "adm_$switch", $colapse[$switch] );
 }
 
-echo "<form action=options.php method=post name=options>" .
-    "<center><table width=95% bgcolor=\"$color[5]\"><tr><td>".
-    "<table width=100% cellspacing=0 bgcolor=\"$color[4]\">" ,
-    "<tr bgcolor=\"$color[5]\"><th colspan=2>" . _("Configuration Administrator") . "</th></tr>",
-    "<tr bgcolor=\"$color[5]\"><td colspan=2 align=\"center\">";
-
-echo "<small>";
-echo _("Note: it is recommended that you configure your system using conf.pl, and not this plugin. conf.pl contains additional information regarding the purpose of variables and appropriate values, as well as additional verification steps.");
-echo "<br />";
-echo _("Run or consult conf.pl should you run into difficulty with your configuration.");
-echo "</small></td></tr>";
+echo '<form action="options.php" method="post" name="options">' .
+     '<table width="95%" align="center" bgcolor="'.$color[5].'"><tr><td>'.
+     '<table width="100%" cellspacing="0" bgcolor="'.$color[4].'">'.
+     '<tr bgcolor="'.$color[5].'"><th colspan="2">'.
+     _("Configuration Administrator").'</th></tr>'.
+     '<tr bgcolor="'.$color[5].'"><td colspan="2" align="center"><small>'.
+     _("Note: it is recommended that you configure your system using conf.pl, and not this plugin. conf.pl contains additional information regarding the purpose of variables and appropriate values, as well as additional verification steps.").
+     '<br />'.
+     _("Run or consult conf.pl should you run into difficulty with your configuration.").
+     '</small></td></tr>';
 
 
 $act_grp = 'Titles';  /* Active group */
@@ -302,12 +320,16 @@ foreach ( $newcfg as $k => $v ) {
         $type = SMOPT_TYPE_PLUGINS;
     } else if ( substr( $k, 0, 13 ) == '$ldap_server[' ) {
         $type = SMOPT_TYPE_LDAP;
+    } else if ( substr( $k, 0, 9 ) == '$fontsets' ||
+	substr( $k, 0, 13 ) == '$aTemplateSet' ) {
+        $type = SMOPT_TYPE_CUSTOM;
     }
 
-    if( $type == SMOPT_TYPE_TITLE || $colapse[$act_grp] == 'off' ) {
+    if ( $type == SMOPT_TYPE_TITLE || $colapse[$act_grp] == 'off' ) {
 
         switch ( $type ) {
         case SMOPT_TYPE_LDAP:
+        case SMOPT_TYPE_CUSTOM:
         case SMOPT_TYPE_PLUGINS:
         case SMOPT_TYPE_THEME:
         case SMOPT_TYPE_HIDDEN:
@@ -315,7 +337,7 @@ foreach ( $newcfg as $k => $v ) {
         case SMOPT_TYPE_EXTERNAL:
             echo "<tr><td>$name</td><td><b>" .
                  $defcfg[$k]['value'] .
-                 "</b></td></tr>";
+                 '</b></td></tr>';
             break;
         case SMOPT_TYPE_TITLE:
             if ( $colapse[$k] == 'on' ) {
@@ -323,9 +345,9 @@ foreach ( $newcfg as $k => $v ) {
             } else {
                 $sw = '(-)';
             }
-            echo "<tr bgcolor=\"$color[0]\"><th colspan=2>" .
-                 "<a href=options.php?switch=$k STYLE=\"text-decoration:none\"><b>$sw</b> </a>" .
-                 "$name</th></tr>";
+            echo '<tr bgcolor="'.$color[0].'"><th colspan="2">'.
+                 "<a href=\"options.php?switch=$k\" style=\"text-decoration:none\">".
+                 '<b>'.$sw.'</b></a> '.$name.'</th></tr>';
             $act_grp = $k;
             break;
         case SMOPT_TYPE_COMMENT:
@@ -339,20 +361,21 @@ foreach ( $newcfg as $k => $v ) {
             echo "</td></tr>\n";
             break;
         case SMOPT_TYPE_INTEGER:
-	    /* look for variable $e in POST, fill into $v */
-            if ( sqgetGlobalVar($e, $v, SQ_POST) ) {
-                $v = intval( $v );
+            /* look for variable $e in POST, fill into $v */
+            if ( sqgetGlobalVar($e, $new_v, SQ_POST) ) {
+                $v = intval( $new_v );
                 $newcfg[$k] = $v;
             }
             echo "<tr><td>$name</td><td>".
-                 "<input size=10 name=\"adm_$n\" value=\"$v\">";
+                 "<input size=\"10\" name=\"adm_$n\" value=\"$v\" />";
             if ( isset( $defcfg[$k]['comment'] ) ) {
                 echo ' &nbsp; ' . $defcfg[$k]['comment'];
             }
             echo "</td></tr>\n";
             break;
         case SMOPT_TYPE_NUMLIST:
-            if (  sqgetGlobalVar($e, $v, SQ_POST) ) {
+            if (  sqgetGlobalVar($e, $new_v, SQ_POST) ) {
+                $v = $new_v;
                 $newcfg[$k] = $v;
             }
             echo "<tr><td>$name</td><td>";
@@ -360,7 +383,7 @@ foreach ( $newcfg as $k => $v ) {
             foreach ( $defcfg[$k]['posvals'] as $kp => $vp ) {
                 echo "<option value=\"$kp\"";
                 if ( $kp == $v ) {
-                    echo ' selected';
+                    echo ' selected="selected"';
                 }
                 echo ">$vp</option>";
             }
@@ -371,8 +394,8 @@ foreach ( $newcfg as $k => $v ) {
             echo "</td></tr>\n";
             break;
         case SMOPT_TYPE_STRLIST:
-            if (  sqgetGlobalVar($e, $v, SQ_POST) ) {
-                $v = '"' . $v . '"';
+            if (  sqgetGlobalVar($e, $new_v, SQ_POST) ) {
+                $v = '"' . $new_v . '"';
                 $newcfg[$k] = $v;
             }
             echo "<tr><td>$name</td><td>".
@@ -380,7 +403,7 @@ foreach ( $newcfg as $k => $v ) {
             foreach ( $defcfg[$k]['posvals'] as $kp => $vp ) {
                 echo "<option value=\"$kp\"";
                 if ( $kp == substr( $v, 1, strlen( $v ) - 2 ) ) {
-                    echo ' selected';
+                    echo ' selected="selected"';
                 }
                 echo ">$vp</option>";
             }
@@ -392,20 +415,20 @@ foreach ( $newcfg as $k => $v ) {
             break;
 
         case SMOPT_TYPE_TEXTAREA:
-            if (  sqgetGlobalVar($e, $v, SQ_POST) ) {
-                $v = '"' . $v . '"';
+            if (  sqgetGlobalVar($e, $new_v, SQ_POST) ) {
+                $v = '"' . $new_v . '"';
                 $newcfg[$k] = str_replace( "\n", '', $v );
             }
-            echo "<tr><td valign=top>$name</td><td>".
-                 "<textarea cols=\"$size\" name=\"adm_$n\">" . substr( $v, 1, strlen( $v ) - 2 ) . "</textarea>";
+            echo "<tr><td valign=\"top\">$name</td><td>".
+                 "<textarea cols=\"$size\" rows=\"4\" name=\"adm_$n\">" . substr( $v, 1, strlen( $v ) - 2 ) . "</textarea>";
             if ( isset( $defcfg[$k]['comment'] ) ) {
                 echo ' &nbsp; ' . $defcfg[$k]['comment'];
             }
             echo "</td></tr>\n";
             break;
         case SMOPT_TYPE_STRING:
-            if (  sqgetGlobalVar($e, $v, SQ_POST) ) {
-                $v = '"' . $v . '"';
+            if (  sqgetGlobalVar($e, $new_v, SQ_POST) ) {
+                $v = '"' . $new_v . '"';
                 $newcfg[$k] = $v;
             }
             if ( $v == '""' && isset( $defcfg[$k]['default'] ) ) {
@@ -413,49 +436,51 @@ foreach ( $newcfg as $k => $v ) {
                 $newcfg[$k] = $v;
             }
             echo "<tr><td>$name</td><td>".
-                 "<input size=\"$size\" name=\"adm_$n\" value=\"" . substr( $v, 1, strlen( $v ) - 2 ) . "\">";
+                 "<input size=\"$size\" name=\"adm_$n\" value=\"" . substr( $v, 1, strlen( $v ) - 2 ) . '" />';
             if ( isset( $defcfg[$k]['comment'] ) ) {
                 echo ' &nbsp; ' . $defcfg[$k]['comment'];
             }
             echo "</td></tr>\n";
             break;
         case SMOPT_TYPE_BOOLEAN:
-            if (  sqgetGlobalVar($e, $v, SQ_POST) ) {
+            if (  sqgetGlobalVar($e, $new_v, SQ_POST) ) {
+                $v = $new_v;
                 $newcfg[$k] = $v;
             } else {
                 $v = strtoupper( $v );
             }
             if ( $v == 'TRUE' ) {
-                $ct = ' checked';
+                $ct = ' checked="checked"';
                 $cf = '';
             } else {
                 $ct = '';
-                $cf = ' checked';
+                $cf = ' checked="checked"';
             }
             echo "<tr><td>$name</td><td>" .
-                 "<INPUT$ct type=radio NAME=\"adm_$n\" value=\"TRUE\">" . _("Yes") .
-                 "<INPUT$cf type=radio NAME=\"adm_$n\" value=\"FALSE\">" . _("No");
+                 "<input$ct type=\"radio\" name=\"adm_$n\" value=\"TRUE\" />" . _("Yes") .
+                 "<input$cf type=\"radio\" name=\"adm_$n\" value=\"FALSE\" />" . _("No");
             if ( isset( $defcfg[$k]['comment'] ) ) {
                 echo ' &nbsp; ' . $defcfg[$k]['comment'];
             }
             echo "</td></tr>\n";
             break;
-	case SMOPT_TYPE_PATH:
-            if (  sqgetGlobalVar($e, $v, SQ_POST) ) {
-               $v = change_to_sm_path($v);
-               $newcfg[$k] = $v;
+        case SMOPT_TYPE_PATH:
+            if (  sqgetGlobalVar($e, $new_v, SQ_POST) ) {
+                // FIXME: fix use of $data_dir in $attachment_dir
+                $v = change_to_sm_path($new_v);
+                $newcfg[$k] = $v;
             }
             if ( $v == "''" && isset( $defcfg[$k]['default'] ) ) {
                $v = change_to_sm_path($defcfg[$k]['default']);
                $newcfg[$k] = $v;
             }
-	    echo "<tr><td>$name</td><td>".
-                 "<input size=\"$size\" name=\"adm_$n\" value=\"" . change_to_rel_path($v) . "\">";
+            echo "<tr><td>$name</td><td>".
+                 "<input size=\"$size\" name=\"adm_$n\" value=\"" . change_to_rel_path($v) . '" />';
             if ( isset( $defcfg[$k]['comment'] ) ) {
                  echo ' &nbsp; ' . $defcfg[$k]['comment'];
             }
-	    echo "</td></tr>\n";
-	    break;
+            echo "</td></tr>\n";
+            break;
         default:
             echo "<tr><td>$name</td><td>" .
                  "<b><i>$v</i></b>";
@@ -487,15 +512,15 @@ if ( $colapse['Group7'] == 'off' ) {
         $e2 = "theme_path_$i";
         if (  sqgetGlobalVar($e, $v2, SQ_POST) ) {
             $v2 = change_to_sm_path($v2);
-	    $newcfg[$k2] = $v2;
+            $newcfg[$k2] = $v2;
         } else {
             $v2 = $newcfg[$k2];
         }
         $name = substr( $v1, 1, strlen( $v1 ) - 2 );
         $path = change_to_rel_path($v2);
         echo '<tr>'.
-             "<td align=right>$i. <input name=\"$e1\" value=\"$name\" size=30></td>".
-             "<td><input name=\"$e2\" value=\"$path\" size=40></td>".
+             "<td align=\"right\">$i. <input name=\"$e1\" value=\"$name\" size=\"30\" /></td>".
+             "<td><input name=\"$e2\" value=\"$path\" size=\"40\" /></td>".
              "</tr>\n";
         $i++;
 
@@ -508,80 +533,90 @@ if ( $colapse['Group8'] == 'on' ) {
 } else {
     $sw = '(-)';
 }
-echo "<tr bgcolor=\"$color[0]\"><th colspan=2>" .
-     "<a href=options.php?switch=Group8 STYLE=\"text-decoration:none\"><b>$sw</b> </a>" .
-     _("Plugins") . '</th></tr>';
+echo '<tr bgcolor="'.$color[0].'"><th colspan="2">'.
+     '<a href="options.php?switch=Group8" style="text-decoration:none"><b>'.
+     $sw.'</b></a> '._("Plugins").'</th></tr>';
 
-if( $colapse['Group8'] == 'off' ) {
+if ( $colapse['Group8'] == 'off' ) {
 
-  $plugpath = SM_PATH . 'plugins/';
-  if ( file_exists($plugpath) ) {
-      $fd = opendir( $plugpath );
-      $op_plugin = array();
-      $p_count = 0;
-      while (false !== ($file = readdir($fd))) {
-        if ($file != '.' && $file != '..' && $file != 'CVS' && is_dir($plugpath . $file) ) {
-            $op_plugin[] = $file;
-            $p_count++;
-        }
-      }
-      closedir($fd);
-      asort( $op_plugin );
-
-      /* Lets get the plugins that are active */
-      $plugins = array();
-      if (  sqgetGlobalVar('plg', $v, SQ_POST) ) {
-        foreach ( $op_plugin as $plg ) {
-            if (  sqgetGlobalVar("plgs_$plg", $v, SQ_POST) && $v == 'on' ) {
-                $plugins[] = $plg;
+    $plugpath = SM_PATH . 'plugins/';
+    if ( file_exists($plugpath) ) {
+        $fd = opendir( $plugpath );
+        $op_plugin = array();
+        $p_count = 0;
+        while (false !== ($file = readdir($fd))) {
+            if ($file != '.' && $file != '..' && $file != 'CVS' && is_dir($plugpath . $file) ) {
+                $op_plugin[] = $file;
+                $p_count++;
             }
         }
-        $i = 0;
-        foreach ( $plugins as $plg ) {
-            $k = "\$plugins[$i]";
-            $newcfg[$k] = "'$plg'";
-            $i++;
-        }
-        while ( isset( $newcfg["\$plugins[$i]"] ) ) {
-            $k = "\$plugins[$i]";
-            $newcfg[$k] = '';
-            $i++;
-        }
-      } else {
-        $i = 0;
-        while ( isset( $newcfg["\$plugins[$i]"] ) ) {
-            $k = "\$plugins[$i]";
-            $v = $newcfg[$k];
-            $plugins[] = substr( $v, 1, strlen( $v ) - 2 );
-            $i++;
-        }
-      }
-      echo "<tr><td colspan=2><input type=hidden name=plg value=on><center><table><tr><td>";
-      foreach ( $op_plugin as $plg ) {
-        if ( in_array( $plg, $plugins ) ) {
-            $sw = ' checked';
+        closedir($fd);
+        asort( $op_plugin );
+
+        /* Lets get the plugins that are active */
+        $plugins = array();
+        if ( sqgetGlobalVar('plg', $v, SQ_POST) ) {
+            foreach ( $op_plugin as $plg ) {
+                if (  sqgetGlobalVar("plgs_$plg", $v2, SQ_POST) && $v2 == 'on' ) {
+                    $plugins[] = $plg;
+                }
+            }
+            $i = 0;
+            foreach ( $plugins as $plg ) {
+                $k = "\$plugins[$i]";
+                $newcfg[$k] = "'$plg'";
+                $i++;
+            }
+            while ( isset( $newcfg["\$plugins[$i]"] ) ) {
+                $k = "\$plugins[$i]";
+                $newcfg[$k] = '';
+                $i++;
+            }
         } else {
-            $sw = '';
+            $i = 0;
+            while ( isset( $newcfg["\$plugins[$i]"] ) ) {
+                $k = "\$plugins[$i]";
+                $v = $newcfg[$k];
+                $plugins[] = substr( $v, 1, strlen( $v ) - 2 );
+                $i++;
+            }
         }
-        echo '<tr>' .
-             "<td>$plg</td><td><input$sw type=checkbox name=plgs_$plg></td>".
-             "</tr>\n";
-      }
-      echo '</td></tr></table></td></tr>';
-  } else {
-      echo '<tr><td colspan=2 align="center">Plugin directory could not be found: ' . $plugpath . "</td></tr>\n";
-  }
+        echo '<tr><td colspan="2"><input type="hidden" name="plg" value="on" /><table align="center">';
+        foreach ( $op_plugin as $plg ) {
+            if ( in_array( $plg, $plugins ) ) {
+                $sw = ' checked="checked"';
+            } else {
+                $sw = '';
+            }
+            echo '<tr><td>';
+            if (file_exists(SM_PATH . "plugins/$plg/README")) {
+                echo "<a href=\"../$plg/README\" target=\"_blank\">$plg</a>";
+            } else {
+                echo $plg;
+            }
+            echo "</td>\n".
+                 "<td><input$sw type=\"checkbox\" name=\"plgs_$plg\" /></td>".
+                 "</tr>\n";
+        }
+        echo '</table></td></tr>';
+    } else {
+        echo '<tr><td colspan="2" align="center">'.
+             sprintf(_("Plugin directory could not be found: %s"), $plugpath).
+             "</td></tr>\n";
+    }
 }
-echo "<tr bgcolor=\"$color[5]\"><th colspan=2><input value=\"" .
-     _("Change Settings") . "\" type=submit></th></tr>" ,
+echo '<tr bgcolor="'.$color[5].'"><th colspan="2"><input value="'.
+     _("Change Settings").'" type="submit" /><br />'.
+     '<a href="'.SM_PATH.'src/configtest.php" target="_blank">'.
+     _("Test Configuration")."</a></th></tr>\n".
      '</table></td></tr></table></form>';
 
 /*
     Write the options to the file.
 */
 
-if( $fp = @fopen( $cfgfile, 'w' ) ) {
-    fwrite( $fp, "<?PHP\n".
+if ( $fp = @fopen( $cfgfile, 'w' ) ) {
+    fwrite( $fp, "<?php\n".
     "/**\n".
     " * SquirrelMail Configuration File\n".
     " * Created using the Administrator Plugin\n".
@@ -590,20 +625,25 @@ if( $fp = @fopen( $cfgfile, 'w' ) ) {
     "global \$version;\n" );
 
     foreach ( $newcfg as $k => $v ) {
-        if ( $k{0} == '$' && $v <> '' ) {
+        if ( $k{0} == '$' && $v <> '' || is_int($v)) {
             if ( substr( $k, 1, 11 ) == 'ldap_server' ) {
                 $v = substr( $v, 0, strlen( $v ) - 1 ) . "\n)";
                 $v = str_replace( 'array(', "array(\n\t", $v );
                 $v = str_replace( "',", "',\n\t", $v );
             }
+            /* FIXME: add elseif that reverts plugins[#] to plugins[] */
             fwrite( $fp, "$k = $v;\n" );
         }
     }
+    // add local config support
+    fwrite( $fp, "@include SM_PATH . 'config/config_local.php';\n" );
+    // close php
     fwrite( $fp, '?>' );
     fclose( $fp );
 } else {
-    echo '<font size=+1><br>'.
+    echo '<br /><p align="center"><big>'.
          _("Config file can't be opened. Please check config.php.").
-         '</font>';
+         '</big></p>';
 }
 ?>
+</body></html>
\ No newline at end of file
