@@ -1,35 +1,111 @@
 <?php
 
 /**
- * Message and Spam Filter Plugin
+ * Message and Spam Filter Plugin - Filtering Functions
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
- * This plugin filters your inbox into different folders based upon given
- * criteria.  It is most useful for people who are subscibed to mailing lists
- * to help organize their messages.  The argument stands that filtering is
- * not the place of the client, which is why this has been made a plugin for
- * SquirrelMail.  You may be better off using products such as Sieve or
- * Procmail to do your filtering so it happens even when SquirrelMail isn't
- * running.
- *
- * If you need help with this, or see improvements that can be made, please
- * email me directly at the address above.  I definately welcome suggestions
- * and comments.  This plugin, as is the case with all SquirrelMail plugins,
- * is not directly supported by the developers.  Please come to me off the
- * mailing list if you have trouble with it.
- *
- * Also view plugins/README.plugins for more information.
- *
- * $Id: filters.php,v 1.52 2004/01/03 13:31:26 tokul Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: filters.php,v 1.83 2006/02/10 23:06:50 stekkel Exp $
  * @package plugins
  * @subpackage filters
  */
 
+/** @ignore */
+if (! defined('SM_PATH')) define('SM_PATH','../../');
+
+/** load globals */
+global $UseSeparateImapConnection,
+    $AllowSpamFilters, $SpamFilters_YourHop, $SpamFilters_ShowCommercial,
+    $SpamFilters_DNScache, $SpamFilters_BulkQuery, $SpamFilters_SharedCache,
+    $SpamFilters_CacheTTL;
+
+/** load default config */
+if (file_exists(SM_PATH . 'plugins/filters/config_default.php')) {
+    include_once (SM_PATH . 'plugins/filters/config_default.php');
+} else {
+    // default config was removed.
+    $UseSeparateImapConnection = false;
+    $AllowSpamFilters = true;
+    $SpamFilters_YourHop = ' ';
+    $SpamFilters_ShowCommercial = false;
+    $SpamFilters_DNScache = array();
+    $SpamFilters_BulkQuery = '';
+    $SpamFilters_SharedCache = true;
+    $SpamFilters_CacheTTL = 7200;
+}
+
+if (file_exists(SM_PATH . 'config/filters_config.php')) {
+    include_once (SM_PATH . 'config/filters_config.php');
+} elseif (file_exists(SM_PATH . 'plugins/filters/config.php')) {
+    include_once (SM_PATH . 'plugins/filters/config.php');
+}
+
 /**
-*
-*/
+ * Init Hooks
+ * @access private
+ */
+function filters_init_hooks () {
+    global $squirrelmail_plugin_hooks;
+
+    if (! sqgetGlobalVar('mailbox',$mailbox,SQ_FORM)) {
+        $mailbox = 'INBOX';
+    }
+
+    $squirrelmail_plugin_hooks['left_main_before']['filters'] = 'start_filters_hook';
+    if (isset($mailbox) && $mailbox == 'INBOX') {
+        $squirrelmail_plugin_hooks['right_main_after_header']['filters'] = 'start_filters_hook';
+    }
+    $squirrelmail_plugin_hooks['optpage_register_block']['filters'] = 'filters_optpage_register_block_hook';
+    $squirrelmail_plugin_hooks['special_mailbox']['filters'] = 'filters_special_mailbox';
+    $squirrelmail_plugin_hooks['rename_or_delete_folder']['filters'] = 'update_for_folder_hook';
+    $squirrelmail_plugin_hooks['webmail_bottom']['filters'] = 'start_filters_hook';
+    $squirrelmail_plugin_hooks['folder_status']['filters'] = 'filters_folder_status';
+}
+
+/**
+ * Register option blocks
+ * @access private
+ */
+function filters_optpage_register_block() {
+    global $optpage_blocks, $AllowSpamFilters;
+
+    $optpage_blocks[] = array(
+        'name' => _("Message Filters"),
+        'url'  => SM_PATH . 'plugins/filters/options.php',
+        'desc' => _("Filtering enables messages with different criteria to be automatically filtered into different folders for easier organization."),
+        'js'   => false
+    );
+
+    if ($AllowSpamFilters) {
+        $optpage_blocks[] = array(
+            'name' => _("SPAM Filters"),
+            'url'  => SM_PATH . 'plugins/filters/spamoptions.php',
+            'desc' => _("SPAM filters allow you to select from various DNS based blacklists to detect junk email in your INBOX and move it to another folder (like Trash)."),
+            'js'   => false
+        );
+    }
+}
+
+/* Receive the status of the folder and do something with it */
+function filters_folder_status($statusarr) {
+
+	global $filter_inbox_count;
+	if (empty($filter_inbox_count)) $filter_inbox_count=0;
+
+    //echo "GOT HOOK<br><pre>";
+    //var_dump($statusarr);
+    //echo "</pre><br>\n";
+
+	if ($statusarr['MAILBOX'] == 'INBOX')
+    {
+     if (!empty($statusarr['MESSAGES'])) $filter_inbox_count=$statusarr['MESSAGES'];
+    }
+}
+
+/**
+ * Saves the DNS Cache to disk
+ * @access private
+ */
 function filters_SaveCache () {
     global $data_dir, $SpamFilters_DNScache;
 
@@ -46,7 +122,7 @@ function filters_SaveCache () {
        $fp = fopen($data_dir . '/dnscache', 'r');
        flock($fp,LOCK_EX);
     }
-    $fp1=fopen($data_dir . '/dnscache', 'w+');
+    $fp1 = fopen($data_dir . '/dnscache', 'w+');
 
     foreach ($SpamFilters_DNScache as $Key=> $Value) {
        $tstr = $Key . ',' . $Value['L'] . ',' . $Value['T'] . "\n";
@@ -57,6 +133,10 @@ function filters_SaveCache () {
     fclose($fp);
 }
 
+/**
+ * Loads the DNS Cache from disk
+ * @access private
+ */
 function filters_LoadCache () {
     global $data_dir, $SpamFilters_DNScache;
 
@@ -64,20 +144,25 @@ function filters_LoadCache () {
         $SpamFilters_DNScache = array();
         if ($fp = fopen ($data_dir . '/dnscache', 'r')) {
             flock($fp,LOCK_SH);
-            while ($data=fgetcsv($fp,1024)) {
+            while ($data = fgetcsv($fp,1024)) {
                if ($data[2] > time()) {
                   $SpamFilters_DNScache[$data[0]]['L'] = $data[1];
                   $SpamFilters_DNScache[$data[0]]['T'] = $data[2];
                }
             }
-
             flock($fp,LOCK_UN);
         }
     }
 }
 
+/**
+ * Uses the BulkQuery executable to query all the RBLs at once
+ * @param array $filters Array of SPAM Fitlers
+ * @param array $IPs Array of IP Addresses
+ * @access private
+ */
 function filters_bulkquery($filters, $IPs) {
-    global $SpamFilters_YourHop, $attachment_dir, $username,
+    global $attachment_dir, $username,
            $SpamFilters_DNScache, $SpamFilters_BulkQuery,
            $SpamFilters_CacheTTL;
 
@@ -113,53 +198,88 @@ function filters_bulkquery($filters, $IPs) {
     }
 }
 
+/**
+ * Starts the filtering process
+ * @access private
+ */
 function start_filters() {
-    global $mailbox, $imapServerAddress, $imapPort, $imap,
-           $imap_general, $filters, $imap_stream, $imapConnection,
-           $UseSeparateImapConnection, $AllowSpamFilters;
+    global $imapServerAddress, $imapPort, $imap_stream, $imapConnection,
+           $UseSeparateImapConnection, $AllowSpamFilters, $filter_inbox_count;
 
     sqgetGlobalVar('username', $username, SQ_SESSION);
     sqgetGlobalVar('key',      $key,      SQ_COOKIE);
 
-#    if ($mailbox == 'INBOX') {
-        // Detect if we have already connected to IMAP or not.
-        // Also check if we are forced to use a separate IMAP connection
-        if ((!isset($imap_stream) && !isset($imapConnection)) ||
-            $UseSeparateImapConnection) {
-                $stream = sqimap_login($username, $key, $imapServerAddress,
-                                    $imapPort, 10);
-                $previously_connected = false;
-        } elseif (isset($imapConnection)) {
-            $stream = $imapConnection;
-            $previously_connected = true;
-        } else {
-            $previously_connected = true;
-            $stream = $imap_stream;
-        }
+    $filters = load_filters();
 
-        if (sqimap_get_num_messages($stream, 'INBOX') > 0) {
-            // Filter spam from inbox before we sort them into folders
-            if ($AllowSpamFilters) {
-                spam_filters($stream);
+    // No point running spam filters if there aren't any to run //
+    if ($AllowSpamFilters) {
+        $spamfilters = load_spam_filters();
+
+        $AllowSpamFilters = false;
+        foreach($spamfilters as $filterskey=>$value) {
+            if ($value['enabled'] == 'yes') {
+                $AllowSpamFilters = true;
+                break;
             }
+        }
+    }
 
-            // Sort into folders
-            user_filters($stream);
+    if (!$AllowSpamFilters && empty($filters)) {
+        return;
+    }
+
+
+    // Detect if we have already connected to IMAP or not.
+    // Also check if we are forced to use a separate IMAP connection
+    if ((!isset($imap_stream) && !isset($imapConnection)) ||
+        $UseSeparateImapConnection ) {
+            $stream = sqimap_login($username, $key, $imapServerAddress,
+                                $imapPort, 10);
+            $previously_connected = false;
+    } else if (isset($imapConnection)) {
+        $stream = $imapConnection;
+        $previously_connected = true;
+    } else {
+        $previously_connected = true;
+        $stream = $imap_stream;
+    }
+
+    if (!isset($filter_inbox_count)) {
+        $aStatus = sqimap_status_messages ($stream, 'INBOX', array('MESSAGES'));
+        if (!empty($aStatus['MESSAGES'])) {
+            $filter_inbox_count=$aStatus['MESSAGES'];
+        } else {
+            $filter_inbox_count=0;
+        }
+    }
+
+    if ($filter_inbox_count > 0) {
+        sqimap_mailbox_select($stream, 'INBOX');
+        // Filter spam from inbox before we sort them into folders
+        if ($AllowSpamFilters) {
+            spam_filters($stream);
         }
 
-        if (!$previously_connected) {
-            sqimap_logout($stream);
-        }
-#    }
+        // Sort into folders
+        user_filters($stream);
+    }
+
+    if (!$previously_connected) {
+        sqimap_logout($stream);
+    }
 }
 
+/**
+ * Does the loop through each filter
+ * @param stream imap_stream the stream to read from
+ * @access private
+ */
 function user_filters($imap_stream) {
     global $data_dir, $username;
     $filters = load_filters();
     if (! $filters) return;
     $filters_user_scan = getPref($data_dir, $username, 'filters_user_scan');
 
-    sqimap_mailbox_select($imap_stream, 'INBOX');
     $expunge = false;
     // For every rule
     for ($i=0, $num = count($filters); $i < $num; $i++) {
@@ -173,6 +293,12 @@ function user_filters($imap_stream) {
                   $filters[$i]['what'], $filters[$i]['folder'], $filters_user_scan, $expunge);
             $expunge = filter_search_and_delete($imap_stream, 'CC',
                   $filters[$i]['what'], $filters[$i]['folder'], $filters_user_scan, $expunge);
+        } else if ($filters[$i]['where'] == 'Header and Body') {
+            $expunge = filter_search_and_delete($imap_stream, 'TEXT',
+                  $filters[$i]['what'], $filters[$i]['folder'], $filters_user_scan, $expunge);
+        } else if ($filters[$i]['where'] == 'Message Body') {
+            $expunge = filter_search_and_delete($imap_stream, 'BODY',
+                  $filters[$i]['what'], $filters[$i]['folder'], $filters_user_scan, $expunge);
         } else {
             /*
             *  If it's a normal TO, CC, SUBJECT, or FROM, then handle it
@@ -189,15 +315,32 @@ function user_filters($imap_stream) {
     }
 }
 
-function filter_search_and_delete($imap_stream, $where, $what, $where_to, $user_scan, 
+/**
+ * Creates and runs the IMAP command to filter messages
+ * @param string $where Which part of the message to search (TO, CC, SUBJECT, etc...)
+ * @param string $what String to search for
+ * @param string $where_to Folder it will move to
+ * @param string $user_scan Whether to search all or just unseen
+ * @param string $should_expunge
+ * @param boolean $where Which part of location to search
+ * @access private
+ */
+function filter_search_and_delete($imap_stream, $where, $what, $where_to, $user_scan,
                                   $should_expunge) {
-    global $languages, $squirrelmail_language, $allow_charset_search, 
-           $uid_support, $imap_server_type;
+    global $languages, $squirrelmail_language, $allow_charset_search, $imap_server_type;
+
+    //TODO: make use of new mailbox cache. See mailbox_display.phpinfo
+
+    if (strtolower($where_to) == 'inbox') {
+        return array();
+    }
+
     if ($user_scan == 'new') {
         $category = 'UNSEEN';
     } else {
         $category = 'ALL';
     }
+    $category .= ' UNDELETED';
 
     if ($allow_charset_search &&
         isset($languages[$squirrelmail_language]['CHARSET']) &&
@@ -210,48 +353,72 @@ function filter_search_and_delete($imap_stream, $where, $what, $where_to, $user_
     }
     if ($where == 'Header') {
         $what  = explode(':', $what);
+        $where = strtoupper($where);
         $where = trim($where . ' ' . $what[0]);
         $what  = addslashes(trim($what[1]));
     }
 
-    if ($imap_server_type == 'macosx') {    
-	$search_str .= ' ' . $where . ' ' . $what;
+    // see comments in squirrelmail sqimap_search function
+    if ($imap_server_type == 'macosx' || $imap_server_type == 'hmailserver') {
+         $search_str .= ' ' . $where . ' ' . $what;
+        /* read data back from IMAP */
+        $read = sqimap_run_command($imap_stream, $search_str, true, $response, $message, TRUE);
     } else {
-	$search_str .= ' ' . $where . ' {' . strlen($what) . "}\r\n"
-                    . $what . "\r\n";
+        $search_str .= ' ' . $where . ' {' . strlen($what) . "}";
+        $sid = sqimap_session_id(true);
+        fputs ($imap_stream, $sid . ' ' . $search_str . "\r\n");
+        $read2 = sqimap_fgets($imap_stream);
+        # server should respond with Ready for argument, then we will send search text
+        #echo "RR2 $read2<br>";
+        fputs ($imap_stream, "$what\r\n");
+        #echo "SS $what<br>";
+        $read2 = sqimap_fgets($imap_stream);
+        #echo "RR2 $read2<br>";
+        $read[]=$read2;
+        $read3 = sqimap_fgets($imap_stream);
+        #echo "RR3 $read3<br>";
+        list($rtag,$response,$message)=explode(' ',$read3,3);
+##        $read2 = sqimap_retrieve_imap_response($imap_stream, $sid, true,
+##              $response, $message, $search_str, false, true, false);
+        #echo "RR2 $read2 / RESPONSE $response<br>";
     }
 
-    /* read data back from IMAP */
-    $read = sqimap_run_command($imap_stream, $search_str, true, $response, $message, $uid_support);
-
-    // This may have problems with EIMS due to it being goofy
-
-    for ($r=0, $num = count($read); $r < $num &&
-                substr($read[$r], 0, 8) != '* SEARCH'; $r++) {}
-    if ($response == 'OK') {
-        $ids = explode(' ', $read[$r]);
-        
-        if (sqimap_mailbox_exists($imap_stream, $where_to)) {
-            $del_id = array();
-            for ($j=2, $num = count($ids); $j < $num; $j++) {
-                $id = trim($ids[$j]);
-                if (is_numeric($id)) {
-                    $del_id[] = $id;
-                }
+    if (isset($read[0])) {
+        $ids = array();
+        for ($i = 0, $iCnt = count($read); $i < $iCnt; ++$i) {
+            if (preg_match("/^\* SEARCH (.+)$/", $read[$i], $regs)) {
+                $ids += preg_split("/ /", trim($regs[1]));
             }
-            if (count($del_id)) {
-                $should_expunge = true;
-                sqimap_msgs_list_move ($imap_stream, $del_id, $where_to);
-                // sqimap_mailbox_expunge($imap_stream, 'INBOX');
+        }
+        if ($response == 'OK' && count($ids)) {
+            if (sqimap_mailbox_exists($imap_stream, $where_to)) {
+                 $should_expunge = true;
+                 sqimap_msgs_list_move ($imap_stream, $ids, $where_to, false);
+            }
+        } elseif ($response != 'OK') {
+            if ($response == 'NO') {
+                $query = $search_str . "\r\n".$what ."\r\n";
+                if (strpos($message,'BADCHARSET') !== false ||
+                    strpos($message,'character') !== false) {
+                    sqm_trigger_imap_error('SQM_IMAP_BADCHARSET',$query, $response, $message);
+                } else {
+                    sqm_trigger_imap_error('SQM_IMAP_ERROR',$query, $response, $message);
+                }
+            } else {
+                sqm_trigger_imap_error('SQM_IMAP_ERROR',$query, $response, $message);
             }
         }
     }
     return $should_expunge;
 }
 
-// These are the spam filters
+/**
+ * Loops through all the Received Headers to find IP Addresses
+ * @param stream imap_stream the stream to read from
+ * @access private
+ */
 function spam_filters($imap_stream) {
-    global $data_dir, $username, $uid_support;
+    global $data_dir, $username;
     global $SpamFilters_YourHop;
     global $SpamFilters_DNScache;
     global $SpamFilters_SharedCache;
@@ -280,52 +447,50 @@ function spam_filters($imap_stream) {
         return;
     }
 
-    sqimap_mailbox_select($imap_stream, 'INBOX');
-
     // Ask for a big list of all "Received" headers in the inbox with
     // flags for each message.  Kinda big.
-    
-    // MGK, removed FLAGS from query. It wasn't used.
-    if ($filters_spam_scan != 'new') {
-        $query = 'FETCH 1:* (BODY.PEEK[HEADER.FIELDS (Received)])';
-    } else {
-        $read = sqimap_run_command($imap_stream, 'SEARCH UNSEEN', true, $response, $message, $uid_support);
-        if ($response != 'OK' || trim($read[0]) == '* SEARCH') {
-    	    $query = 'FETCH 1:* (BODY.PEEK[HEADER.FIELDS (RECEIVED)])';
-        } else {
-            if (isset($read[0])) {
-                if (preg_match("/^\* SEARCH (.+)$/", $read[0], $regs)) {
+
+    if ($filters_spam_scan == 'new') {
+        $search_array = array();
+        $read = sqimap_run_command($imap_stream, 'SEARCH UNSEEN', true, $response, $message, TRUE);
+        if (isset($read[0])) {
+            for ($i = 0, $iCnt = count($read); $i < $iCnt; ++$i) {
+                if (preg_match("/^\* SEARCH (.+)$/", $read[$i], $regs)) {
                     $search_array = preg_split("/ /", trim($regs[1]));
+                break;
                 }
             }
-            $msgs_str = sqimap_message_list_squisher($search_array);
-            $query =  'FETCH ' . $msgs_str . ' (BODY.PEEK[HEADER.FIELDS (RECEIVED)])';
-	    }
+        }
     }
-    $headers = filter_get_headers ($imap_stream, $query);    
-    if (!$headers) {
+    if ($filters_spam_scan == 'new' && count($search_array)) {
+        $headers = sqimap_get_small_header_list ($imap_stream, $search_array, array('Received'),array());
+    } else if ($filters_spam_scan != 'new') {
+        $headers = sqimap_get_small_header_list ($imap_stream, null , array('Received'),array());
+    } else {
+        return;
+    }
+    if (!count($headers)) {
         return;
     }
-    
     $bulkquery = (strlen($SpamFilters_BulkQuery) > 0 ? true : false);
     $IPs = array();
     $aSpamIds = array();
     foreach ($headers as $id => $aValue) {
-        if (isset($aValue['UID'])) { 
+        if (isset($aValue['UID'])) {
             $MsgNum = $aValue['UID'];
         } else {
             $MsgNum = $id;
         }
         // Look through all of the Received headers for IP addresses
-        if (isset($aValue['HEADER']['Received'])) {
-            foreach ($aValue['HEADER']['Received'] as $received) {
+        if (isset($aValue['RECEIVED'])) {
+            foreach ($aValue['RECEIVED'] as $received) {
                 // Check to see if this line is the right "Received from" line
                 // to check
-                
-                // $aValue['HEADER']['Received'] is an array with all the received lines.
+
+                // $aValue['Received'] is an array with all the received lines.
                 // We should check them from bottom to top and only check the first 2.
                 // Currently we check only the header where $SpamFilters_YourHop in occures
-                
+
                 if (is_int(strpos($received, $SpamFilters_YourHop))) {
                     if (preg_match('/([0-9]{1,3})\.([0-9]{1,3})\.([0-9]{1,3})\.([0-9]{1,3})/',$received,$aMatch)) {
                         $isspam = false;
@@ -372,8 +537,17 @@ function spam_filters($imap_stream) {
     }
 }
 
-// Does the loop through each enabled filter for the specified IP address.
-// IP format:  $a.$b.$c.$d
+/**
+ * Does the loop through each enabled filter for the specified IP address.
+ * IP format:  $a.$b.$c.$d
+ * @param int $a First subset of IP
+ * @param int $b Second subset of IP
+ * @param int $c Third subset of IP
+ * @param int $d Forth subset of IP
+ * @param array $filters The Spam Filters
+ * @return boolean Whether the IP is Spam
+ * @access private
+ */
 function filters_spam_check_site($a, $b, $c, $d, &$filters) {
     global $SpamFilters_DNScache, $SpamFilters_CacheTTL;
     foreach ($filters as $key => $value) {
@@ -404,11 +578,16 @@ function filters_spam_check_site($a, $b, $c, $d, &$filters) {
     return 0;
 }
 
+/**
+ * Loads the filters from the user preferences
+ * @return array All the user filters
+ * @access private
+ */
 function load_filters() {
     global $data_dir, $username;
 
     $filters = array();
-    for ($i=0; $fltr = getPref($data_dir, $username, 'filter' . $i); $i++) {
+    for ($i = 0; $fltr = getPref($data_dir, $username, 'filter' . $i); $i++) {
         $ary = explode(',', $fltr);
         $filters[$i]['where'] = $ary[0];
         $filters[$i]['what'] = $ary[1];
@@ -417,6 +596,11 @@ function load_filters() {
     return $filters;
 }
 
+/**
+ * Loads the Spam Filters and checks the preferences for the enabled status
+ * @return array All the spam filters
+ * @access private
+ */
 function load_spam_filters() {
     global $data_dir, $username, $SpamFilters_ShowCommercial;
 
@@ -435,7 +619,7 @@ function load_spam_filters() {
         $filters['MAPS RSS']['dns'] = 'relays.mail-abuse.org';
         $filters['MAPS RSS']['result'] = '127.0.0.2';
         $filters['MAPS RSS']['comment'] =
-            _("COMMERCIAL - Servers that are configured (or misconfigured) to allow spam to be relayed through their system will be banned with this.  Another good one to use.");
+            _("COMMERCIAL - Servers that are configured (or misconfigured) to allow spam to be relayed through their system will be banned with this. Another good one to use.");
 
         $filters['MAPS DUL']['prefname'] = 'filters_spam_maps_dul';
         $filters['MAPS DUL']['name'] = 'MAPS Dial-Up List';
@@ -443,7 +627,7 @@ function load_spam_filters() {
         $filters['MAPS DUL']['dns'] = 'dialups.mail-abuse.org';
         $filters['MAPS DUL']['result'] = '127.0.0.3';
         $filters['MAPS DUL']['comment'] =
-            _("COMMERCIAL - Dial-up users are often filtered out since they should use their ISP's mail servers to send mail.  Spammers typically get a dial-up account and send spam directly from there.");
+            _("COMMERCIAL - Dial-up users are often filtered out since they should use their ISP's mail servers to send mail. Spammers typically get a dial-up account and send spam directly from there.");
 
         $filters['MAPS RBLplus-RBL']['prefname'] = 'filters_spam_maps_rblplus_rbl';
         $filters['MAPS RBLplus-RBL']['name'] = 'MAPS RBL+ RBL List';
@@ -556,7 +740,7 @@ function load_spam_filters() {
     $filters['SPAMcop']['dns'] = 'bl.spamcop.net';
     $filters['SPAMcop']['result'] = '127.0.0.2';
     $filters['SPAMcop']['comment'] =
-        _("FREE, for now - SPAMCOP - An interesting solution that lists servers that have a very high spam to legit email ratio (85 percent or more).");
+        _("FREE, for now - SpamCop - An interesting solution that lists servers that have a very high spam to legit email ratio (85 percent or more).");
 
     $filters['dev.null.dk']['prefname'] = 'filters_spam_devnull';
     $filters['dev.null.dk']['name'] = 'dev.null.dk Lists';
@@ -687,18 +871,21 @@ function load_spam_filters() {
         _("FREE - Distributed Sender Boycott List - UN-Confirmed Relays");
 
     foreach ($filters as $Key => $Value) {
-        $filters[$Key]['enabled'] = getPref($data_dir, $username,
-            $filters[$Key]['prefname']);
+        $filters[$Key]['enabled'] = getPref($data_dir, $username, $filters[$Key]['prefname']);
     }
 
     return $filters;
 }
 
+/**
+ * Removes a User filter
+ * @param int $id ID of the filter to remove
+ * @access private
+ */
 function remove_filter ($id) {
     global $data_dir, $username;
 
-    while ($nextFilter = getPref($data_dir, $username, 'filter' .
-        ($id + 1))) {
+    while ($nextFilter = getPref($data_dir, $username, 'filter' . ($id + 1))) {
         setPref($data_dir, $username, 'filter' . $id, $nextFilter);
         $id ++;
     }
@@ -706,6 +893,12 @@ function remove_filter ($id) {
     removePref($data_dir, $username, 'filter' . $id);
 }
 
+/**
+ * Swaps two filters
+ * @param int $id1 ID of first filter to swap
+ * @param int $id2 ID of second filter to swap
+ * @access private
+ */
 function filter_swap($id1, $id2) {
     global $data_dir, $username;
 
@@ -718,18 +911,22 @@ function filter_swap($id1, $id2) {
     }
 }
 
-/* This update the filter rules when
-   renaming or deleting folders */
+/**
+ * This updates the filter rules when renaming or deleting folders
+ * @param array $args
+ * @access private
+ */
 function update_for_folder ($args) {
+
     $old_folder = $args[0];
-        $new_folder = $args[2];
-        $action = $args[1];
-    global $plugins, $data_dir, $username;
+    $new_folder = $args[2];
+    $action = $args[1];
+    global $data_dir, $username;
     $filters = array();
     $filters = load_filters();
     $filter_count = count($filters);
     $p = 0;
-    for ($i=0;$i<$filter_count;$i++) {
+    for ($i = 0; $i < $filter_count; $i++) {
         if (!empty($filters)) {
             if ($old_folder == $filters[$i]['folder']) {
                 if ($action == 'rename') {
@@ -746,125 +943,18 @@ function update_for_folder ($args) {
         }
     }
 }
-/*
- * Function extracted from sqimap_get_small_header_list.
- * The unused FETCH arguments and HEADERS are disabled.
+
+/**
+ * Display formated error message
+ * @param string $string text message
+ * @return string html formated text message
+ * @access private
  */
-function filter_get_headers ($imap_stream, $query) {
-    global $uid_support;
-    /* Get the small headers for each message in $msg_list */
-
-    $read_list = sqimap_run_command_list ($imap_stream, $query, false, $response, $message, $uid_support);
-
-    if (isset($response) && $response != 'OK') {
-        return false;
-    }
-
-
-    foreach ($read_list as $r) {
-        $read = implode('',$r);
-        /* 
-            * #id<space>FETCH<space>(
-        */
-        /* extract the message id */
-        $i_space = strpos($read,' ',2);
-        $id = substr($read,2,$i_space-2);
-        $fetch = substr($read,$i_space+1,5);
-        if (!is_numeric($id) && $fetch !== 'FETCH') {
-            set_up_language($squirrelmail_language);
-            echo '<br><b><font color=$color[2]>' .
-                 _("ERROR : Could not complete request.") .
-                 '</b><br>' .
-                 _("Unknown response from IMAP server: ") . ' 1.' .
-                 htmlspecialchars($read) . "</font><br>\n";
-                 break;
-        }
-        $i = strpos($read,'(',$i_space+5);
-        $read = substr($read,$i+1);
-        $i_len = strlen($read);
-        $i = 0;
-        while ($i < $i_len && $i !== false) {
-            /* get argument */
-            $read = trim(substr($read,$i));
-            $i_len = strlen($read);
-            $i = strpos($read,' ');
-            $arg = substr($read,0,$i);
-            ++$i;
-            switch ($arg)
-            {
-            case 'UID':
-                $i_pos = strpos($read,' ',$i);
-                if (!$i_pos) {
-                    $i_pos = strpos($read,')',$i);
-                }
-                if ($i_pos) {
-                    $unique_id = substr($read,$i,$i_pos-$i);
-                    $i = $i_pos+1;
-                } else {
-                    break 3;
-                }
-                $msgs[$id]['UID'] = $unique_id;
-                break;
-            // case 'FLAGS':
-            //    $flags = parseArray($read,$i);
-            //    if (!$flags) break 3;
-            //    $msgs[$id]['FLAGS'] = $flags;
-            //    break;
-            // case 'RFC822.SIZE':
-            //    $i_pos = strpos($read,' ',$i);
-            //    if (!$i_pos) {
-            //        $i_pos = strpos($read,')',$i);
-            //    }
-            //    if ($i_pos) {
-            //        $size = substr($read,$i,$i_pos-$i);
-            //        $i = $i_pos+1;
-            //    } else {
-            //        break 3;
-            //    }
-            //    $msgs[$id]['SIZE'] = $size;
-            //    
-            //    break;
-            // case 'INTERNALDATE':
-            //    $msgs[$id]['INTERNALDATE'] = parseString($read,$i);
-            //    break;
-            case 'BODY.PEEK[HEADER.FIELDS':
-            case 'BODY[HEADER.FIELDS':
-                $i = strpos($read,'{',$i);
-                $header = parseString($read,$i);
-                if ($header === false) break 3;
-                /* First we unfold the header */
-                $hdr = trim(str_replace(array("\r\n\t", "\r\n "),array('', ''), $header));
-                /* Now we can make a new header array with */
-                /* each element representing a headerline  */
-                $hdr = explode("\r\n" , $hdr);
-                foreach ($hdr as $line) {
-                    $pos = strpos($line, ':');
-                    if ($pos > 0) {
-                        $field = strtolower(substr($line, 0, $pos));
-                        if (!strstr($field,' ')) { /* valid field */
-                            $value = trim(substr($line, $pos+1));
-                            switch($field) {
-                            case 'received':    $msgs[$id]['HEADER']['Received'][] =       $value; break;
-                            // case 'to':          $msgs[$id]['HEADER']['To']=             $value; break;
-                            // case 'cc':          $msgs[$id]['HEADER']['Cc'] =            $value; break;
-                            // case 'from':        $msgs[$id]['HEADER']['From'] =          $value; break;
-                            // case 'date':        $msgs[$id]['HEADER']['Date'] =          $value; break;
-                            // case 'x-priority':  $msgs[$id]['HEADER']['Prio'] =          $value; break;
-                            // case 'subject':     $msgs[$id]['HEADER']['Subject'] =       $value; break;
-                            // case 'content-type':$msgs[$id]['HEADER']['Content-Type'] =  $value; break;
-                            default: break;
-                            }
-                        }
-                    }
-                }
-                break;
-            default:
-                ++$i;
-                break;
-            }
-        }
-    }
-    return $msgs;
+function do_error($string) {
+    global $color;
+    echo "<p align=\"center\"><font color=\"$color[2]\">";
+    echo $string;
+    echo "</font></p>\n";
 }
 
-?>
\ No newline at end of file
+?>
