@@ -1,25 +1,28 @@
-<?PHP
+<?php
 
 /**
  * functions for info plugin
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * Here are two functions for the info plugin
  * The first gets the CAPABILITY response from your IMAP server.
- * The second runs the passed IMAP test and returns the results 
+ * The second runs the passed IMAP test and returns the results
  * The third prints the results of the IMAP command
  * to options.php.
- * by: Jason Munro jason@stdbev.com
  *
- * $Id: functions.php,v 1.5 2003/10/27 22:24:39 tassium Exp $ 
+ * @author Jason Munro <jason at stdbev.com>
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: functions.php,v 1.14 2006/01/23 18:42:22 tokul Exp $
  * @package plugins
  * @subpackage info
  */
 
 /**
  * Get the IMAP capabilities
+ *
+ * @param mixed $imap_stream
  * @return array
+ * @access private
  */
 function get_caps($imap_stream) {
     return sqimap_run_command_list($imap_stream, 'CAPABILITY',false, $responses, $message,false);
@@ -27,11 +30,14 @@ function get_caps($imap_stream) {
 
 /**
  * Run an IMAP test and return the results
+ *
+ * @param mixed $imap_stream
+ * @param string $string imap command
  * @return array Response from the IMAP server
+ * @access private
  */
 function imap_test($imap_stream, $string) {
-    global $default_charset;
-    print "<TR><TD>".$string."</TD></TR>";
+    print "<tr><td>".htmlspecialchars($string)."</td></tr>";
     $response = sqimap_run_command_list($imap_stream, trim($string),false, $responses, $message,false);
     array_push($response, $responses . ' ' .$message);
     return $response;
@@ -39,6 +45,9 @@ function imap_test($imap_stream, $string) {
 
 /**
  * Print the IMAP response to options.php
+ *
+ * @param array $response results of imap command
+ * @access private
  */
 function print_response($response) {
     foreach($response as $index=>$value) {
@@ -46,11 +55,9 @@ function print_response($response) {
             print_response($value);
         }
         else {
-            $value = preg_replace("/</", "&lt;", $value);
-            $value = preg_replace("/>/", "&gt;", $value);
-            print $value."<BR>\n";
+            print htmlspecialchars($value)."<br />\n";
         }
     }
 }
-                                                                                        
-?>
+
+?>
\ No newline at end of file
