@@ -1,29 +1,36 @@
 <?php
-/** Message Source  
-*
-* Plugin to view the RFC822 raw message output and the bodystructure of a message
-*
-* Copyright (c) 2002 Marc Groot Koerkamp, The Netherlands
-* Licensed under the GNU GPL. For full terms see the file COPYING.
-* 
-* $Id: setup.php,v 1.5 2003/12/01 21:56:50 cigamit Exp $
-* @package plugins
-* @subpackage message_details
-**/
+
+/**
+ * Message Details plugin - main setup script
+ *
+ * Plugin to view the RFC822 raw message output and the bodystructure of a message
+ *
+ * @author Marc Groot Koerkamp
+ * @copyright &copy; 2002 Marc Groot Koerkamp, The Netherlands
+ * @copyright &copy; 2002-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: setup.php,v 1.15 2006/02/05 11:32:33 jervfors Exp $
+ * @package plugins
+ * @subpackage message_details
+ **/
 
 /**
  * Initialize the plugin
+ * @access private
  */
 function squirrelmail_plugin_init_message_details()
 {
   global $squirrelmail_plugin_hooks;
 
-  do_hook('read_body_header_right');
   $squirrelmail_plugin_hooks['read_body_header_right']['message_details'] = 'show_message_details';
 }
 
+/**
+ * Add message details link in message view
+ * @access private
+ */
 function show_message_details() {
-    global $passed_id, $mailbox, $ent_num, $color,
+    global $passed_id, $mailbox, $ent_num,
            $javascript_on;
 
     if (strlen(trim($mailbox)) < 1) {
@@ -39,7 +46,7 @@ function show_message_details() {
     $result = '';
     /* Output the link. */
     if ($javascript_on) {
-        $result = '<script type="text/javascript" language="javascript">' . "\n" .
+        $result = '<script type="text/javascript">' . "\n" .
                 '<!--' . "\n" .
                 "  function MessageSource() {\n" .
                 '    window.open("../plugins/message_details/message_details_main.php' .
@@ -47,9 +54,9 @@ function show_message_details() {
                 "  }\n" .
                 "// -->\n" .
                 "</script>\n" .
-                "&nbsp;|&nbsp;<A HREF=\"javascript:MessageSource();\">$print_text</A>\n";
-    } 
+                "&nbsp;|&nbsp;<a href=\"javascript:MessageSource();\">$print_text</a>\n";
+    }
     echo $result;
 }
- 
-?>
+
+?>
\ No newline at end of file
