@@ -3,10 +3,9 @@
 /**
  * testsound.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.        
- *
- * $Id: testsound.php,v 1.13 2003/10/27 22:24:40 tassium Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: testsound.php,v 1.26 2006/02/05 11:18:50 jervfors Exp $
  * @package plugins
  * @subpackage newmail
  */
@@ -16,20 +15,18 @@ define('SM_PATH','../../');
 
 /* SquirrelMail required files. */
 require_once(SM_PATH . 'include/validate.php');
-require_once(SM_PATH . 'functions/global.php');
-require_once(SM_PATH . 'functions/html.php');
 
 displayHtmlHeader( _("Test Sound"), '', FALSE );
 
-echo '<body bgcolor="'.$color[4].'" topmargin=0 leftmargin=0 rightmargin=0 marginwidth=0 marginheight=0>'."\n";
+echo '<body bgcolor="'.$color[4].'" topmargin="0" leftmargin="0" rightmargin="0" marginwidth="0" marginheight="0">'."\n";
 
 if ( ! sqgetGlobalVar('sound', $sound, SQ_GET) ) {
     $sound = 'Click.wav';
 } elseif ( $sound == '(none)' ) {
-    echo '<center><form><br /><br />'.
+    echo '<div style="text-align: center;"><form><br /><br />'.
          '<b>' . _("No sound specified") . '</b><br /><br />'.
-         '<input type="button" name="close" value="' . _("Close") . '" onClick="window.close()">'.
-         '</form></center>'.
+         '<input type="button" name="close" value="' . _("Close") . '" onclick="window.close()" />'.
+         '</form></div>'.
          '</body></html>';
     return;
 }
@@ -37,16 +34,16 @@ if ( ! sqgetGlobalVar('sound', $sound, SQ_GET) ) {
 echo html_tag( 'table',
          html_tag( 'tr',
              html_tag( 'td',
-                    "<embed src=\"$sound\" hidden=true autostart=true>".
-                    '<br>'.
-                    '<b>' . _("Loading the sound...") . '</b><br>'.
+                    newmail_create_media_tags($sound)."\n".
+                    '<br />'.
+                    '<b>' . _("Loading the sound...") . '</b><br />'.
                     '<form>'.
                     '<input type="button" name="close" value="  ' .
                     _("Close") .
-                    '  " onClick="window.close()">'.
+                    '  " onclick="window.close()" />'.
                     '</form>' ,
                 'center' )
             ) ,
         'center' ) .
         '</body></html>';
-?>
+?>
\ No newline at end of file
