@@ -3,17 +3,19 @@
 /**
  * empty_trash.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * Handles deleting messages from the trash folder without
  * deleting subfolders.
  *
- * $Id: empty_trash.php,v 1.48 2003/12/01 21:56:55 cigamit Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: empty_trash.php,v 1.57 2006/02/05 11:31:22 tokul Exp $
  * @package squirrelmail
  */
 
-/** Path for SquirrelMail required files. */
+/**
+ * Path for SquirrelMail required files.
+ * @ignore
+ */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -65,9 +67,14 @@ for ($i = 0; $i < $numboxes; $i++) {
 
 // now lets go through the tree and delete the folders
 walkTreeInPreOrderEmptyTrash(0, $imap_stream, $foldersTree);
+// update mailbox cache
+$mailboxes=sqimap_get_mailboxes($imap_stream,true,$show_only_subscribed_folders);
+sqimap_logout($imap_stream);
+
+// close session properly before redirecting
+session_write_close();
 
 $location = get_location();
 header ("Location: $location/left_main.php");
 
-sqimap_logout($imap_stream);
-?>
+?>
\ No newline at end of file
