@@ -3,20 +3,22 @@
 /**
  * help.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * Displays help for the user
  *
- * $Id: help.php,v 1.46 2003/12/01 21:56:55 cigamit Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: help.php,v 1.64 2006/02/05 12:23:04 jervfors Exp $
  * @package squirrelmail
  */
 
-/** Path for SquirrelMail required files. */
+/**
+ * Path for SquirrelMail required files.
+ * @ignore
+ */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
-require_once(SM_PATH . 'include/validate.php');
+include_once(SM_PATH . 'include/validate.php');
 require_once(SM_PATH . 'functions/global.php');
 require_once(SM_PATH . 'functions/display_messages.php');
 
@@ -48,8 +50,8 @@ function get_info($doc, $pos) {
     for ($n=$pos; $n < $cntdoc; $n++) {
         if (trim(strtolower($doc[$n])) == '<chapter>'
             || trim(strtolower($doc[$n])) == '<section>') {
-            for ($n++; $n < $cntdoc 
-                 && (trim(strtolower($doc[$n])) != '</section>') 
+            for ($n++; $n < $cntdoc
+                 && (trim(strtolower($doc[$n])) != '</section>')
                  && (trim(strtolower($doc[$n])) != '</chapter>'); $n++) {
                 if (trim(strtolower($doc[$n])) == '<title>') {
                     $n++;
@@ -57,7 +59,7 @@ function get_info($doc, $pos) {
                 }
                 if (trim(strtolower($doc[$n])) == '<description>') {
                     $ary[1] = '';
-                    for ($n++;$n < $cntdoc 
+                    for ($n++;$n < $cntdoc
                          && (trim(strtolower($doc[$n])) != '</description>');
                          $n++) {
                         $ary[1] .= $doc[$n];
@@ -65,8 +67,8 @@ function get_info($doc, $pos) {
                 }
                 if (trim(strtolower($doc[$n])) == '<summary>') {
                     $ary[2] = '';
-                    for ($n++; $n < $cntdoc 
-                         && (trim(strtolower($doc[$n])) != '</summary>'); 
+                    for ($n++; $n < $cntdoc
+                         && (trim(strtolower($doc[$n])) != '</summary>');
                          $n++) {
                         $ary[2] .= $doc[$n];
                     }
@@ -79,13 +81,13 @@ function get_info($doc, $pos) {
                 $ary[1] = $ary[0];
                 $ary[2] = $ary[0];
             }
-	    return( $ary );
+            return( $ary );
         } else if (!trim(strtolower($doc[$n]))) {
-	     $ary[0] = '';
-	     $ary[1] = '';
-	     $ary[2] = '';
-	     $ary[3] = $n;
-	}
+            $ary[0] = '';
+            $ary[1] = '';
+            $ary[2] = '';
+            $ary[3] = $n;
+        }
     }
     $ary[0] = _("ERROR: Help files are not in the right format!");
     $ary[1] = $ary[0];
@@ -99,7 +101,7 @@ function get_info($doc, $pos) {
 
 echo html_tag( 'table',
         html_tag( 'tr',
-            html_tag( 'td','<center><b>' . _("Help") .'</b></center>', 'center', $color[0] )
+            html_tag( 'td','<div style="text-align: center;"><b>' . _("Help") .'</b></div>', 'center', $color[0] )
         ) ,
     'center', '', 'width="95%" cellpadding="1" cellspacing="2" border="0"' );
 
@@ -116,9 +118,9 @@ if (!isset($squirrelmail_language)) {
 if (file_exists("../help/$squirrelmail_language")) {
     $user_language = $squirrelmail_language;
 } else if (file_exists('../help/en_US')) {
-    echo "<center><font color=\"$color[2]\">";
-    printf (_("The help has not been translated to %s.  It will be displayed in English instead."), $languages[$squirrelmail_language]['NAME']);
-    echo '</font></center><br>';
+    echo "<div style=\"text-align: center;\"><font color=\"$color[2]\">"
+        ._("The help has not been translated to the selected language. It will be displayed in English instead.");
+    echo '</font></div><br />';
     $user_language = 'en_US';
 } else {
     error_box( _("Some or all of the help documents are not present!"), $color );
@@ -148,10 +150,10 @@ if ( sqgetGlobalVar('chapter', $temp, SQ_GET) ) {
 }
 
 if ( $chapter == 0 || !isset( $helpdir[$chapter-1] ) ) {
-    echo html_tag( 'table', '', 'center', '', 'cellpadding="0" cellspacing="0" border="0"' );
-	        html_tag( 'tr' ) .
-                    html_tag( 'td' ) .
-                         '<b><center>' . _("Table of Contents") . '</center></b><br>';
+    echo html_tag( 'table', '', 'center', '', 'cellpadding="0" cellspacing="0" border="0"' ) .
+         html_tag( 'tr' ) .
+         html_tag( 'td' ) .
+         '<div style="text-align: center;"><b>' . _("Table of Contents") . '</b></div><br />';
     echo html_tag( 'ol' );
     for ($i=0, $cnt = count($helpdir); $i < $cnt; $i++) {
         $doc = file("../help/$user_language/$helpdir[$i]");
@@ -165,7 +167,7 @@ if ( $chapter == 0 || !isset( $helpdir[$chapter-1] ) ) {
 } else {
     $doc = file("../help/$user_language/" . $helpdir[$chapter-1]);
     $help_info = get_info($doc, 0);
-    echo '<small><center>';
+    echo '<div style="text-align: center;"><small>';
     if ($chapter <= 1){
         echo '<font color="' . $color[9] . '">' . _("Previous")
              . '</font> | ';
@@ -180,33 +182,37 @@ if ( $chapter == 0 || !isset( $helpdir[$chapter-1] ) ) {
         echo ' | <a href="../src/help.php?chapter=' . ($chapter+1)
              . '">' . _("Next") . '</a>';
     }
-    echo '</center></small><br>';
+    echo '</small></div><br />';
 
     echo '<font size="5"><b>' . $chapter . ' - ' . $help_info[0]
-         . '</b></font><br><br>';
+         . '</b></font><br /><br />';
 
     if (isset($help_info[1]) && $help_info[1]) {
         echo $help_info[1];
     } else {
         echo html_tag( 'p', $help_info[2], 'left' );
     }
-             
+
     $section = 0;
     for ($n = $help_info[3], $cnt = count($doc); $n < $cnt; $n++) {
         $section++;
         $help_info = get_info($doc, $n);
         echo "<b>$chapter.$section - $help_info[0]</b>" .
             html_tag( 'ul', $help_info[1] );
-    	$n = $help_info[3];
+        $n = $help_info[3];
     }
 
-    echo '<br><center><a href="#pagetop">' . _("Top") . '</a></center>';
+    echo '<br /><div style="text-align: center;"><a href="#pagetop">' . _("Top") . '</a></div>';
 }
 
 do_hook('help_bottom');
 
 echo html_tag( 'tr',
             html_tag( 'td', '&nbsp;', 'left', $color[0] )
-        ).
-       '</table></body></html>';
+        );
+
 ?>
+</table>
+<?php
+$oTemplate->display('footer.tpl');
+?>
\ No newline at end of file
