@@ -3,20 +3,22 @@
 /**
  * image.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This file shows an attached image
  *
- * $Id: image.php,v 1.22 2003/12/01 21:56:55 cigamit Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: image.php,v 1.32 2006/02/05 11:18:50 jervfors Exp $
  * @package squirrelmail
  */
 
-/** Path for SquirrelMail required files. */
+/**
+ * Path for SquirrelMail required files.
+ * @ignore
+ */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
-require_once(SM_PATH . 'include/validate.php');
+include_once(SM_PATH . 'include/validate.php');
 require_once(SM_PATH . 'functions/global.php');
 require_once(SM_PATH . 'functions/date.php');
 require_once(SM_PATH . 'functions/page_header.php');
@@ -34,11 +36,11 @@ sqgetGlobalVar('ent_id',        $ent_id,        SQ_GET);
 sqgetGlobalVar('QUERY_STRING',  $QUERY_STRING,  SQ_SERVER);
 /* end globals */
 
-echo '<BR>' . 
-    '<TABLE WIDTH="100%" BORDER=0 CELLSPACING=0 CELLPADDING=2 ALIGN=CENTER>' .
+echo '<br />' .
+    '<table width="100%" border="0" cellspacing="0" cellpadding="2" align="center">' .
     "\n" .
-    '<TR><TD BGCOLOR="' . $color[0] . '">' .
-    '<B><CENTER>' .
+    '<tr><td bgcolor="' . $color[0] . '">' .
+    '<div style="text-align: center;"><b>' .
     _("Viewing an image attachment") . " - ";
 
 $msg_url = 'read_body.php?' . $QUERY_STRING;
@@ -47,20 +49,20 @@ echo '<a href="'.$msg_url.'">'. _("View message") . '</a>';
 
 
 $DownloadLink = '../src/download.php?passed_id=' . $passed_id .
-               '&amp;mailbox=' . urlencode($mailbox) . 
+               '&amp;mailbox=' . urlencode($mailbox) .
                '&amp;ent_id=' . urlencode($ent_id) . '&amp;absolute_dl=true';
 
-echo '</b></td></tr>' . "\n" .
-    '<tr><td align=center><A HREF="' . $DownloadLink . '">' .
-    _("Download this as a file") .
-    '</A></B><BR>&nbsp;' . "\n" .
-    '</TD></TR></TABLE>' . "\n" .
-
-    '<TABLE BORDER=0 CELLSPACING=0 CELLPADDING=2 ALIGN=CENTER>' . "\n" .
-    '<TR><TD BGCOLOR="' . $color[4] . '">' .
-    '<img src="' . $DownloadLink . '">' .
-
-    '</TD></TR></TABLE>' . "\n";
-    '</body></html>' . "\n";
-
 ?>
+</b></div></td></tr>
+<tr><td align="center">
+<a href="<?php echo $DownloadLink; ?>"><?php echo _("Download this as a file"); ?></a>
+<br />&nbsp;</td></tr></table>
+
+<table border="0" cellspacing="0" cellpadding="2" align="center">
+<tr><td bgcolor="<?php echo $color[4]; ?>">
+<img src="<?php echo $DownloadLink; ?>" />
+
+</td></tr></table>
+<?php
+$oTemplate->display('footer.tpl');
+?>
\ No newline at end of file
