@@ -3,58 +3,46 @@
 /**
  * options_highlight.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * Displays message highlighting options
  *
- * $Id: options_highlight.php,v 1.53 2003/12/01 21:56:57 cigamit Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: options_highlight.php,v 1.69.2.1 2006/02/17 15:52:52 stekkel Exp $
  * @package squirrelmail
+ * @subpackage prefs
  */
 
-/** Path for SquirrelMail required files. */
+/**
+ * Path for SquirrelMail required files.
+ * @ignore
+ */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
-require_once(SM_PATH . 'include/validate.php');
-require_once(SM_PATH . 'functions/display_messages.php');
-require_once(SM_PATH . 'functions/imap.php');
-require_once(SM_PATH . 'functions/plugin.php');
-require_once(SM_PATH . 'functions/strings.php');
-require_once(SM_PATH . 'functions/html.php');
+include_once(SM_PATH . 'include/validate.php');
+include_once(SM_PATH . 'functions/display_messages.php');
+include_once(SM_PATH . 'functions/imap.php');
+include_once(SM_PATH . 'functions/plugin.php');
+include_once(SM_PATH . 'functions/strings.php');
+include_once(SM_PATH . 'functions/html.php');
+include_once(SM_PATH . 'functions/forms.php');
 
 /* get globals */
-if (isset($_GET['action'])) {
-    $action = $_GET['action'];
-}
-if (isset($_GET['theid'])) {
-    $theid = $_GET['theid'];
-}
-if (isset($_GET['identname'])) {
-    $identname = $_GET['identname'];
-}
-if (isset($_GET['newcolor_choose'])) {
-    $newcolor_choose = $_GET['newcolor_choose'];
-}
-if (isset($_GET['newcolor_input'])) {
-    $newcolor_input = $_GET['newcolor_input'];
-}
-if (isset($_GET['color_type'])) {
-    $color_type = $_GET['color_type'];
-}
-if (isset($_GET['match_type'])) {
-    $match_type = $_GET['match_type'];
-}
-if (isset($_GET['value'])) {
-    $value = $_GET['value'];
-}
+sqGetGlobalVar('action', $action);
+sqGetGlobalVar('theid', $theid);
+sqGetGlobalVar('identname', $identname);
+sqGetGlobalVar('newcolor_choose', $newcolor_choose);
+sqGetGlobalVar('newcolor_input', $newcolor_input);
+sqGetGlobalVar('color_type', $color_type);
+sqGetGlobalVar('match_type', $match_type);
+sqGetGlobalVar('value', $value);
 
 /* end of get globals */
- 
+
 function oh_opt( $val, $sel, $tit ) {
     echo "<option value=\"$val\"";
     if ( $sel )
-        echo ' selected';
+        echo ' selected="selected"';
     echo  ">$tit</option>\n";
 }
 
@@ -94,7 +82,7 @@ if (isset($theid) && ($action == 'delete') ||
             $new_rules = $message_highlight_list;
             break;
     }
-    $message_highlight_list = $new_rules;    
+    $message_highlight_list = $new_rules;
 
     setPref($data_dir, $username, 'hililist', serialize($message_highlight_list));
 
@@ -112,11 +100,11 @@ if (isset($theid) && ($action == 'delete') ||
     $value = str_replace(',', ' ', $value);
 
     if(isset($theid)) {
-        $message_highlight_list[$theid] = 
+        $message_highlight_list[$theid] =
             array( 'name' => $identname, 'color' => $newcolor,
                    'value' => $value, 'match_type' => $match_type );
     } else {
-        $message_highlight_list[] = 
+        $message_highlight_list[] =
             array( 'name' => $identname, 'color' => $newcolor,
                    'value' => $value, 'match_type' => $match_type );
     }
@@ -128,15 +116,15 @@ displayPageHeader($color, 'None');
 echo
 html_tag( 'table', "\n" .
     html_tag( 'tr', "\n" .
-        html_tag( 'td', '<center><b>' . _("Options") . ' - ' . _("Message Highlighting") . '</b></center>', 'left')
+        html_tag( 'td', '<div style="text-align: center;"><b>' . _("Options") . ' - ' . _("Message Highlighting") . '</b></div>', 'left')
     ),
-    'center', $color[9], 'width="95%" border="0" cellpadding="1" cellspacing="0"' ) . "<br>\n" .
-html_tag( 'table', '', '', '', 'width="100%" border="0" cellpadding="1" cellspacing="0"' ) . 
+    'center', $color[9], 'width="95%" border="0" cellpadding="1" cellspacing="0"' ) . "<br />\n" .
+html_tag( 'table', '', '', '', 'width="100%" border="0" cellpadding="1" cellspacing="0"' ) .
      html_tag( 'tr' ) . "\n" .
          html_tag( 'td', '', 'left' );
 
-echo '<center>[<a href="options_highlight.php?action=add">' . _("New") . '</a>]'.
-        ' - [<a href="options.php">'._("Done").'</a>]</center><br>'."\n";
+echo '<div style="text-align: center;">[<a href="options_highlight.php?action=add">' . _("New") . '</a>]'.
+        ' - [<a href="options.php">'._("Done").'</a>]</div><br />'."\n";
 $mhl_count = count($message_highlight_list);
 if ($mhl_count > 0) {
     echo html_tag( 'table', '', 'center', '', 'width="80%" border="0" cellpadding="3" cellspacing="0"' ) . "\n";
@@ -175,7 +163,7 @@ if ($mhl_count > 0) {
         echo html_tag( 'tr',
                     html_tag( 'td',
                         $links,
-                    'left', $color[4], 'width="20%" nowrap' ) .
+                    'left', $color[4], 'width="20%" style="white-space: nowrap;"' ) .
                     html_tag( 'td',
                         htmlspecialchars($message_highlight_list[$i]['name']) ,
                     'left' ) .
@@ -186,10 +174,10 @@ if ($mhl_count > 0) {
                 '', $message_highlight_list[$i]['color'] ) . "\n";
     }
     echo "</table>\n".
-        "<br>\n";
+        "<br />\n";
 } else {
-    echo '<center>' . _("No highlighting is defined") . "</center><br>\n".
-        "<br>\n";
+    echo '<div style="text-align: center;">' . _("No highlighting is defined") . "</div><br />\n".
+        "<br />\n";
 }
 if ($action == 'edit' || $action == 'add') {
 
@@ -329,8 +317,10 @@ if ($action == 'edit' || $action == 'add') {
     $new_color_list["18,3"] = 'ff33ff';
     $new_color_list["18,4"] = 'ff00ff';
 
-    $selected_input = '';
-    $selected_choose = '';
+    $selected_input = FALSE;
+    $selected_i = null;
+    $selected_choose = FALSE;
+    $selected_predefined = FALSE;
 
     for ($i=0; $i < 14; $i++) {
         ${"selected".$i} = '';
@@ -338,8 +328,8 @@ if ($action == 'edit' || $action == 'add') {
     if ($action == 'edit' && isset($theid) && isset($message_highlight_list[$theid]['color'])) {
         for ($i=0; $i < 14; $i++) {
             if ($color_list[$i] == $message_highlight_list[$theid]['color']) {
-                $selected_choose = ' checked';
-                ${"selected".$i} = ' selected';
+                $selected_choose = TRUE;
+                $selected_i = $color_list[$i];
                 continue;
             }
         }
@@ -364,20 +354,21 @@ if ($action == 'edit' || $action == 'add') {
         }
     }
 
-    if (!isset($message_highlight_list[$theid]['color']))
-        $selected_choose = ' checked';
+    if (isset($theid) && !isset($message_highlight_list[$theid]['color']))
+        $selected_choose = TRUE;
     else if ($pre_defined_color)
-        $selected_predefined = ' checked';
+        $selected_predefined = TRUE;
     else if ($selected_choose == '')
-        $selected_input = ' checked';
+        $selected_input = TRUE;
 
-    echo '<form name="f" action="options_highlight.php">' . "\n";
-    echo '<input type="hidden" value="save" name="action">' . "\n";
-    if($action == 'edit')
-        echo '<input type="hidden" value="'.(isset($theid)?$theid:'').'" name="theid">' . "\n";
+    echo addForm('options_highlight.php', 'post', 'f').
+         addHidden('action', 'save');
+    if($action == 'edit') {
+        echo addHidden('theid', (isset($theid)?$theid:''));
+    }
     echo html_tag( 'table', '', 'center', '', 'width="80%" cellpadding="3" cellspacing="0" border="0"' ) . "\n";
     echo html_tag( 'tr', '', '', $color[0] ) . "\n";
-    echo html_tag( 'td', '', 'right', '', 'nowrap' ) . "<b>\n";
+    echo html_tag( 'td', '', 'right', '', 'style="white-space: nowrap;"' ) . "<b>\n";
     echo _("Identifying name") . ":";
     echo '      </b></td>' . "\n";
     echo html_tag( 'td', '', 'left' ) . "\n";
@@ -385,48 +376,55 @@ if ($action == 'edit' || $action == 'add') {
         $disp = $message_highlight_list[$theid]['name'];
     else
         $disp = '';
-    $disp = htmlspecialchars($disp);
-    echo "         <input type=\"text\" value=\"".$disp."\" name=\"identname\">";
+    echo "         ".addInput('identname', $disp);
     echo "      </td>\n";
     echo "   </tr>\n";
     echo html_tag( 'tr', html_tag( 'td', '<small><small>&nbsp;</small></small>', 'left' ) ) ."\n";
     echo html_tag( 'tr', '', '', $color[0] ) . "\n";
     echo html_tag( 'td', '<b>'. _("Color") . ':</b>', 'right' );
     echo html_tag( 'td', '', 'left' );
-    echo "         <input type=\"radio\" name=color_type value=1$selected_choose> &nbsp;<select name=newcolor_choose>\n";
-    echo "            <option value=\"$color_list[0]\"$selected0>" . _("Dark Blue") . "\n";
-    echo "            <option value=\"$color_list[1]\"$selected1>" . _("Dark Green") . "\n";
-    echo "            <option value=\"$color_list[2]\"$selected2>" . _("Dark Yellow") . "\n";
-    echo "            <option value=\"$color_list[3]\"$selected3>" . _("Dark Cyan") . "\n";
-    echo "            <option value=\"$color_list[4]\"$selected4>" . _("Dark Magenta") . "\n";
-    echo "            <option value=\"$color_list[5]\"$selected5>" . _("Light Blue") . "\n";
-    echo "            <option value=\"$color_list[6]\"$selected6>" . _("Light Green") . "\n";
-    echo "            <option value=\"$color_list[7]\"$selected7>" . _("Light Yellow") . "\n";
-    echo "            <option value=\"$color_list[8]\"$selected8>" . _("Light Cyan") . "\n";
-    echo "            <option value=\"$color_list[9]\"$selected9>" . _("Light Magenta") . "\n";
-    echo "            <option value=\"$color_list[10]\"$selected10>" . _("Dark Gray") . "\n";
-    echo "            <option value=\"$color_list[11]\"$selected11>" . _("Medium Gray") . "\n";
-    echo "            <option value=\"$color_list[12]\"$selected12>" . _("Light Gray") . "\n";
-    echo "            <option value=\"$color_list[13]\"$selected13>" . _("White") . "\n";
-    echo "         </select><br>\n";
-    echo "         <input type=\"radio\" name=color_type value=2$selected_input> &nbsp;". _("Other:") ."<input type=\"text\" value=\"";
-    if ($selected_input && isset($theid)) echo $message_highlight_list[$theid]["color"];
-    echo '" name="newcolor_input" size="7"> '._("Ex: 63aa7f")."<br>\n";
+    echo '         '.addRadioBox('color_type', $selected_choose, '1');
+
+    $selops = array (
+        $color_list[0] => _("Dark Blue"),
+        $color_list[1] => _("Dark Green"),
+        $color_list[2] => _("Dark Yellow"),
+        $color_list[3] => _("Dark Cyan"),
+        $color_list[4] => _("Dark Magenta"),
+        $color_list[5] => _("Light Blue"),
+        $color_list[6] => _("Light Green"),
+        $color_list[7] => _("Light Yellow"),
+        $color_list[8] => _("Light Cyan"),
+        $color_list[9] => _("Light Magenta"),
+        $color_list[10] => _("Dark Gray"),
+        $color_list[11] => _("Medium Gray"),
+        $color_list[12] => _("Light Gray"),
+        $color_list[13] => _("White") );
+
+    echo addSelect('newcolor_choose', $selops, $selected_i, TRUE);
+    echo "<br />\n";
+
+    echo '         '.addRadioBox('color_type', $selected_input, 2).
+        ' &nbsp;'. _("Other:") .
+        addInput('newcolor_input',
+            (($selected_input && isset($theid)) ? $message_highlight_list[$theid]['color'] : ''),
+            '7');
+    echo _("Ex: 63aa7f")."<br />\n";
     echo "      </td>\n";
     echo "   </tr>\n";
 
     # Show grid of color choices
     echo html_tag( 'tr', '', '', $color[0] ) . "\n";
     echo html_tag( 'td', '', 'left', '', 'colspan="2"' );
-    echo html_tag( 'table', '', 'center', '', 'border=0 cellpadding="2" cellspacing="1"' ) . "\n";
+    echo html_tag( 'table', '', 'center', '', 'border="0" cellpadding="2" cellspacing="1"' ) . "\n";
 
     for($x = 0; $x < 5; $x++) {
         echo html_tag( 'tr' ) . "\n";
         for($y = 0; $y < 19; $y++) {
         $gridindex = "$y,$x";
         $gridcolor = $new_color_list[$gridindex];
-        $selected = ($gridcolor == $current_color) ? ' checked' : '' ;
-        echo html_tag( 'td', '<input type="radio" name="color_type" value="#' . $gridcolor .'"' . $selected . '>', 'left', $gridcolor, 'colspan="2"' );
+        echo html_tag( 'td', addRadioBox('color_type', ($gridcolor == $current_color), '#'.$gridcolor),
+            'left', '#'.$gridcolor, 'colspan="2"' );
         }
         echo "</tr>\n";
     }
@@ -436,7 +434,7 @@ if ($action == 'edit' || $action == 'add') {
     echo html_tag( 'tr', html_tag( 'td', '<small><small>&nbsp;</small></small>', 'left' ) ) . "\n";
     echo html_tag( 'tr', '', '', $color[0] ) . "\n";
     echo html_tag( 'td', '', 'center', '', 'colspan="2"' ) . "\n";
-    echo "         <select name=match_type>\n";
+    echo "         <select name=\"match_type\">\n";
     oh_opt( 'from',
             (isset($theid)?$message_highlight_list[$theid]['match_type'] == 'from':1),
             _("From") );
@@ -458,15 +456,17 @@ if ($action == 'edit' || $action == 'add') {
         $disp = $message_highlight_list[$theid]['value'];
     else
         $disp = '';
-    $disp = htmlspecialchars($disp);
-    echo '         <input type="text" value="' . $disp .
-        '" name="value" size=40>';
+    echo '         '.addInput('value', $disp, 40);
     echo "        </td>\n";
     echo "   </tr>\n";
     echo "</table>\n";
-    echo '<center><input type="submit" value="' . _("Submit") . "\"></center>\n";
+    echo '<div style="text-align: center;"><input type="submit" value="' . _("Submit") . "\" /></div>\n";
     echo "</form>\n";
 }
 do_hook('options_highlight_bottom');
+
 ?>
-</table></body></html>
+</table>
+<?php
+$oTemplate->display('footer.tpl');
+?>
\ No newline at end of file
