@@ -1,6 +1,6 @@
 <?php
+
 /**
- * @author Luke Ehresman
  * January 2, 2000
  * Theme Name:   'Default Theme'
  * This is the default theme that comes standard with SquirrelMail.
@@ -14,25 +14,31 @@
  * You might want to submit the theme you create to our Patches tracker
  * on http://sourceforge.net/projects/squirrelmail
  * for inclusion in further releases of SquirrelMail.
+ *
+ * @author Luke Ehresman
+ * @copyright &copy; 2000-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: default_theme.php,v 1.12 2006/01/23 18:46:27 tokul Exp $
  * @package squirrelmail
  * @subpackage themes
  **/
 
     global $color;
-    $color[0]   = '#DCDCDC'; // (light gray)     TitleBar
+    $color[0]   = '#dcdcdc'; // (light gray)     TitleBar
     $color[1]   = '#800000'; // (red)
-    $color[2]   = '#CC0000'; // (light red)      Warning/Error Messages
-    $color[3]   = '#A0B8C8'; // (green-blue)     Left Bar Background
-    $color[4]   = '#FFFFFF'; // (white)          Normal Background
-    $color[5]   = '#FFFFCC'; // (light yellow)   Table Headers
+    $color[2]   = '#cc0000'; // (light red)      Warning/Error Messages
+    $color[3]   = '#a0b8c8'; // (green-blue)     Left Bar Background
+    $color[4]   = '#ffffff'; // (white)          Normal Background
+    $color[5]   = '#ffffcc'; // (light yellow)   Table Headers
     $color[6]   = '#000000'; // (black)          Text on left bar
-    $color[7]   = '#0000CC'; // (blue)           Links
+    $color[7]   = '#0000cc'; // (blue)           Links
     $color[8]   = '#000000'; // (black)          Normal text
-    $color[9]   = '#ABABAB'; // (mid-gray)       Darker version of #0
+    $color[9]   = '#ababab'; // (mid-gray)       Darker version of #0
     $color[10]  = '#666666'; // (dark gray)      Darker version of #9
     $color[11]  = '#770000'; // (dark red)       Special Folders color
-    $color[12]  = '#EDEDED'; // (light gray)     Alternate color for message list
+    $color[12]  = '#ededed'; // (light gray)     Alternate color for message list
     $color[13]  = '#800000'; // (dark red)       Color for quoted text -- > 1 quote
-    $color[14]  = '#FF0000'; // (red)            Color for quoted text -- >> 2 or more
+    $color[14]  = '#ff0000'; // (red)            Color for quoted text -- >> 2 or more
     $color[15]  = '#002266'; // (dark blue)      Unselectable folders
-?>
+    $color[16]  = '#ff9933'; // (orange)         Highlight color
+?>
\ No newline at end of file
