@@ -3,16 +3,15 @@
 /**
  * methodical_theme.php
  * Name:    Methodical
- * @author Ray Black III
  * Date:    November 19, 2001
  * Comment: Methodical is a theme that's based on the dompie theme,
  *          but expands the blue across the entire page, and modifies
  *          some of the gray backgrounds.
  *
- * Copyright (c) 2000-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
- * $Id: methodical_theme.php,v 1.5 2003/10/28 20:58:30 tassium Exp $
+ * @author Ray Black III
+ * @copyright &copy; 2000-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: methodical_theme.php,v 1.10 2006/01/23 18:46:27 tokul Exp $
  * @package squirrelmail
  * @subpackage themes
  */
@@ -20,16 +19,16 @@
 global $color;
 $color[0]   = '#808080'; // (middle grey)    TitleBar
 $color[1]   = '#800000'; // (red)
-$color[2]   = '#CC0000'; // (light red)      Warning/Error Messages
+$color[2]   = '#cc0000'; // (light red)      Warning/Error Messages
 $color[3]   = '#294763'; // (dark blue)      Left Bar Background
 $color[4]   = '#294763'; // (white)          Normal Background
 $color[5]   = '#999999'; // (light grey)     Table Headers
-$color[6]   = '#FFFFFF'; // (white)          Text on left bar
-$color[7]   = '#FFFFFF'; // (black)          Links
-$color[8]   = '#FFFFFF'; // (black)          Normal text
+$color[6]   = '#ffffff'; // (white)          Text on left bar
+$color[7]   = '#ffffff'; // (black)          Links
+$color[8]   = '#ffffff'; // (black)          Normal text
 $color[9]   = '#999999'; // (light grey)     Darker version of #0
 $color[10]  = '#999999'; // (light grey)     Darker version of #9
-$color[11]  = '#A7C5F3'; // (light blue)     Special Folders color
-$color[12]  = '#9F9F9F'; // 
-$color[13]  = '#DFDFDF'; // (lighter grey)   Unselectable folders
-?>
+$color[11]  = '#a7c5f3'; // (light blue)     Special Folders color
+$color[12]  = '#9f9f9f'; //
+$color[13]  = '#dfdfdf'; // (lighter grey)   Unselectable folders
+?>
\ No newline at end of file
