@@ -2,14 +2,13 @@
 
 /**
  * Name:    Random Theme Every Login
- * @author  Tyler Akins
  * Date:    December 24, 2001
  * Comment: Guess what this does!
  *
- * Copyright (c) 2000-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
- * $Id: random.php,v 1.8 2003/10/29 15:35:15 tassium Exp $
+ * @author Tyler Akins
+ * @copyright &copy; 2000-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: random.php,v 1.15 2006/01/23 18:46:27 tokul Exp $
  * @package squirrelmail
  * @subpackage themes
  */
@@ -18,9 +17,9 @@
 sq_mt_randomize();
 
 require_once(SM_PATH . 'functions/global.php');
-   
-global $theme, $random_theme_good_themes;
-   
+
+global $theme;
+
 if (!sqsession_is_registered('random_theme_good_theme')) {
     $good_themes = array();
     foreach ($theme as $data) {
@@ -33,9 +32,16 @@ if (!sqsession_is_registered('random_theme_good_theme')) {
     }
     $which = mt_rand(0, count($good_themes));
     $random_theme_good_theme = $good_themes[$which];
+    // remove current sm_path from theme name
+    $path=preg_quote(SM_PATH,'/');
+    $random_theme_good_theme=preg_replace("/^$path/",'',$random_theme_good_theme);
+    // store it in session
     sqsession_register($random_theme_good_theme, 'random_theme_good_theme');
+} else {
+    // get random theme stored in session
+    sqgetGlobalVar('random_theme_good_theme',$random_theme_good_theme);
 }
-   
-@include_once ($random_theme_good_theme);
 
-?>
+@include_once (SM_PATH . $random_theme_good_theme);
+
+?>
\ No newline at end of file
