@@ -2,33 +2,32 @@
 
 /**
  * Name:   Slashdot Theme
- * @author Luke Ehresman
  * Date:   January 3, 2000
  * Comment This theme tries to mimic the color scheme from the
  *         "News for Nerds" web site, www.slashdot.org.
  *
- * Copyright (c) 2000-2003 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
- * $Id: slashdot_theme.php,v 1.7 2003/10/28 20:58:30 tassium Exp $
+ * @author Luke Ehresman
+ * @copyright &copy; 2000-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: slashdot_theme.php,v 1.12 2006/01/23 18:46:27 tokul Exp $
  * @package squirrelmail
  * @subpackage themes
  */
 
 global $color;
-$color[0]   = '#DCDCDC'; // (light gray)     TitleBar
+$color[0]   = '#dcdcdc'; // (light gray)     TitleBar
 $color[1]   = '#800000'; // (red)
-$color[2]   = '#CC0000'; // (light red)      Warning/Error Messages
+$color[2]   = '#cc0000'; // (light red)      Warning/Error Messages
 $color[3]   = '#006668'; // (/. color)       Left Bar Background
-$color[4]   = '#FFFFFF'; // (white)          Normal Background
-$color[5]   = '#BABABA'; // (darker gray)    Table Headers
+$color[4]   = '#ffffff'; // (white)          Normal Background
+$color[5]   = '#bababa'; // (darker gray)    Table Headers
 $color[6]   = '#000000'; // (black)          Text on left bar
 $color[7]   = '#004949'; // (light /. color) Links
 $color[8]   = '#000000'; // (black)          Normal text
-$color[9]   = '#ABABAB'; // (mid-gray)       Darker version of #0
+$color[9]   = '#ababab'; // (mid-gray)       Darker version of #0
 $color[10]  = '#666666'; // (dark gray)      Darker version of #9
 $color[11]  = '#770000'; // (dark red)       Special Folders color
-$color[12]  = '#EAEAEA';
-$color[15]  = '#ABABAB'; // (mid-gray)       Unselectable folders
+$color[12]  = '#eaeaea';
+$color[15]  = '#ababab'; // (mid-gray)       Unselectable folders
 
-?>
+?>
\ No newline at end of file
